@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _BASEGUI_H_
-#define _BASEGUI_H_
+#ifndef BASEGUI_H
+#define BASEGUI_H
 
 #include <QMainWindow>
 #include <QNetworkProxy>
@@ -28,18 +28,25 @@
 #include "config.h"
 #include "guiconfig.h"
 
-#ifdef Q_OS_WIN
 #ifdef AVOID_SCREENSAVER
-/* Disable screensaver by event */
 #include <windows.h>
 #endif
+
+#ifdef MOUSE_GESTURES
+	#define MG_DELAYED_SEEK
 #endif
 
 //#define SHARE_MENU
+//#define DETECT_MINIMIZE_WORKAROUND
+
+#if !defined(Q_OS_WIN) && QT_VERSION >= 0x050000 && QT_VERSION < 0x050501
+#define NUMPAD_WORKAROUND
+#endif
 
 class QWidget;
 class QMenu;
 class LogWindow;
+class InfoWindow;
 class MplayerWindow;
 
 class QLabel;
@@ -62,14 +69,18 @@ class Favorites;
 class TVList;
 class UpdateChecker;
 
-#ifdef SHAREWIDGET
+#ifdef SHARE_WIDGET
 class ShareWidget;
 #endif
 
+#ifndef SHARE_WIDGET
+#define DONATE_REMINDER
+#endif
+
 class BaseGui : public QMainWindow
 {
-    Q_OBJECT
-    
+	Q_OBJECT
+
 public:
 	BaseGui( QWidget* parent = 0, Qt::WindowFlags flags = 0 );
 	~BaseGui();
@@ -118,8 +129,9 @@ public slots:
 	virtual void helpFAQ();
 	virtual void helpCLOptions();
 	virtual void helpCheckUpdates();
-#ifdef REMINDER_ACTIONS
 	virtual void helpDonate();
+#ifndef SHARE_ACTIONS
+	void showHelpDonateDialog(bool * accepted = 0);
 #endif
 	virtual void helpShowConfig();
 	virtual void helpAbout();
@@ -165,6 +177,10 @@ public slots:
 	virtual void showSubDelayDialog();
 	virtual void showAudioDelayDialog();
 	virtual void showStereo3dDialog();
+#ifdef BOOKMARKS
+	virtual void showAddBookmarkDialog();
+	virtual void showBookmarkDialog();
+#endif
 
 	virtual void exitFullscreen();
 	virtual void toggleFullscreen();
@@ -199,6 +215,7 @@ protected slots:
 	virtual void exitFullscreenOnStop();
 	virtual void exitFullscreenIfNeeded();
 	virtual void playlistHasFinished();
+	virtual void addToPlaylistCurrentFile();
 
 	virtual void displayState(Core::State state);
 	virtual void displayMessage(QString message, int time);
@@ -228,7 +245,7 @@ protected slots:
 	void checkIfUpgraded();
 #endif
 
-#if defined(REMINDER_ACTIONS) && !defined(SHAREWIDGET)
+#ifdef DONATE_REMINDER
 	void checkReminder();
 #endif
 
@@ -252,6 +269,7 @@ protected slots:
 	void resizeMainWindow(int w, int h);
 	void resizeWindow(int w, int h);
 	virtual void hidePanel();
+	void centerWindow();
 
 	/* virtual void playlistVisibilityChanged(); */
 
@@ -285,7 +303,11 @@ protected slots:
 	virtual void loadActions();
 	virtual void saveActions();
 
+	virtual void processMouseMovedDiff(QPoint diff);
 	virtual void moveWindowDiff(QPoint diff);
+#ifdef MG_DELAYED_SEEK
+	virtual void delayedSeek();
+#endif
 
 	// Single instance stuff
 #ifdef SINGLE_INSTANCE
@@ -305,11 +327,17 @@ protected slots:
 	virtual void changeStyleSheet(QString style);
 #endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-#ifdef AVOID_SCREENSAVER
-	/* Disable screensaver by event */
+	void applyStyles();
+
+	virtual void setTabletMode(bool);
+
+#ifdef Q_OS_WIN
+	void checkSystemTabletMode();
+	void systemTabletModeChanged(bool);
+	
+	#ifdef AVOID_SCREENSAVER
 	void clear_just_stopped();
-#endif
+	#endif
 #endif
 
 #ifdef LOG_MPLAYER
@@ -328,6 +356,7 @@ signals:
 	void ABMarkersChanged(int secs_a, int secs_b);
 	void videoInfoChanged(int width, int height, double fps);
 	void timeChanged(QString time_ready_to_print);
+	void timeChanged(double current_time);
 
 	/*
 	void wheelUp();
@@ -349,23 +378,31 @@ signals:
 	void guiChanged(QString gui);
 #endif
 
+	void preferencesChanged();
+	void tabletModeChanged(bool new_mode);
+
 protected:
 	virtual void retranslateStrings();
 	virtual void changeEvent(QEvent * event);
-#if QT_VERSION < 0x050000
+#ifndef DETECT_MINIMIZE_WORKAROUND
 	virtual void hideEvent( QHideEvent * );
 	virtual void showEvent( QShowEvent * );
 #else
 	virtual bool event(QEvent * e);
 	bool was_minimized;
 #endif
+
 #ifdef Q_OS_WIN
-	#ifdef AVOID_SCREENSAVER
-	/* Disable screensaver by event */
 	virtual bool winEvent ( MSG * m, long * result );
+	#if QT_VERSION >= 0x050000
+	virtual bool nativeEvent(const QByteArray &eventType, void * message, long * result);
 	#endif
 #endif
 
+#ifdef NUMPAD_WORKAROUND
+	void keyPressEvent(QKeyEvent *event);
+#endif
+
 	virtual void aboutToEnterFullscreen();
 	virtual void aboutToExitFullscreen();
 	virtual void aboutToEnterCompactMode();
@@ -381,12 +418,16 @@ protected:
 	void createPreferencesDialog();
 	void createFilePropertiesDialog();
 	void setDataToFileProperties();
-	void initializeGui();
+
 	void createActions();
 #if AUTODISABLE_ACTIONS
 	void setActionsEnabled(bool);
 #endif
 	void createMenus();
+	virtual void populateMainMenu();
+#ifdef BOOKMARKS
+	void updateBookmarks();
+#endif
 	void updateRecents();
 	void configureDiscDevices();
 	void setupNetworkProxy();
@@ -451,6 +492,9 @@ protected:
 	MyAction * videoEqualizerAct;
 	MyAction * screenshotAct;
 	MyAction * screenshotsAct;
+#ifdef CAPTURE_STREAM
+	MyAction * capturingAct;
+#endif
 #ifdef VIDEOPREVIEW
 	MyAction * videoPreviewAct;
 #endif
@@ -475,8 +519,13 @@ protected:
 	MyAction * incAudioDelayAct;
 	MyAction * audioDelayAct; // Ask for delay
 	MyAction * extrastereoAct;
+#ifdef MPLAYER_SUPPORT
 	MyAction * karaokeAct;
+#endif
 	MyAction * volnormAct;
+#ifdef MPV_SUPPORT
+	MyAction * earwaxAct;
+#endif
 	MyAction * loadAudioAct;
 	MyAction * unloadAudioAct;
 
@@ -492,6 +541,10 @@ protected:
 	MyAction * decSubStepAct;
 	MyAction * incSubScaleAct;
 	MyAction * decSubScaleAct;
+#ifdef MPV_SUPPORT
+	MyAction * seekNextSubAct;
+	MyAction * seekPrevSubAct;
+#endif
 	MyAction * useCustomSubStyleAct;
 	MyAction * useForcedSubsOnlyAct;
 	MyAction * subVisibilityAct;
@@ -513,6 +566,7 @@ protected:
 #ifdef LOG_SMPLAYER
 	MyAction * showLogSmplayerAct;
 #endif
+	MyAction * tabletModeAct;
 
 	// Menu Help
 	MyAction * showFirstStepsAct;
@@ -523,9 +577,7 @@ protected:
 	MyAction * updateYTAct;
 #endif
 	MyAction * showConfigAct;
-#ifdef REMINDER_ACTIONS
 	MyAction * donateAct;
-#endif
 	MyAction * aboutThisAct;
 
 #ifdef SHARE_MENU
@@ -539,6 +591,9 @@ protected:
 	// OSD
 	MyAction * incOSDScaleAct;
 	MyAction * decOSDScaleAct;
+#ifdef MPV_SUPPORT
+	MyAction * OSDFractionsAct;
+#endif
 
 	// Playlist
 	MyAction * playPrevAct;
@@ -686,7 +741,7 @@ protected:
 
 	// Audio Channels Action Group
 	MyActionGroup * channelsGroup;
-	/* MyAction * channelsDefaultAct; */
+	MyAction * channelsDefaultAct;
 	MyAction * channelsStereoAct;
 	MyAction * channelsSurroundAct;
 	MyAction * channelsFull51Act;
@@ -712,8 +767,16 @@ protected:
 	MyActionGroup * secondarySubtitleTrackGroup;
 #endif
 	MyActionGroup * titleGroup;
-	MyActionGroup * angleGroup;
 	MyActionGroup * chapterGroup;
+	MyActionGroup * angleGroup;
+#ifdef BOOKMARKS
+	MyActionGroup * bookmarkGroup;
+	MyAction * addBookmarkAct;
+	MyAction * editBookmarksAct;
+
+	MyAction * prevBookmarkAct;
+	MyAction * nextBookmarkAct;
+#endif
 
 #if DVDNAV_SUPPORT
 	MyAction * dvdnavUpAct;
@@ -733,6 +796,7 @@ protected:
 	QMenu *audioMenu;
 	QMenu *subtitlesMenu;
 	QMenu *browseMenu;
+	QMenu *viewMenu;
 	QMenu *optionsMenu;
 	QMenu *helpMenu;
 
@@ -749,6 +813,9 @@ protected:
 	QMenu * titles_menu;
 	QMenu * chapters_menu;
 	QMenu * angles_menu;
+#ifdef BOOKMARKS
+	QMenu * bookmark_menu;
+#endif
 	QMenu * aspect_menu;
 	QMenu * osd_menu;
 	QMenu * deinterlace_menu;
@@ -763,7 +830,7 @@ protected:
 	QMenu * videofilter_menu;
 	QMenu * audiofilter_menu;
 #if defined(LOG_MPLAYER) || defined(LOG_SMPLAYER)
-	QMenu * logs_menu;
+	//QMenu * logs_menu;
 #endif
 	QMenu * zoom_menu;
 	QMenu * rotate_menu;
@@ -780,6 +847,7 @@ protected:
 
 	QMenu * popup;
 	QMenu * recentfiles_menu;
+	QMenu * access_menu;
 
 #ifdef LOG_MPLAYER
 	LogWindow * mplayer_log_window;
@@ -787,7 +855,7 @@ protected:
 #ifdef LOG_SMPLAYER
 	LogWindow * smplayer_log_window;
 #endif
-	LogWindow * clhelp_window;
+	InfoWindow * clhelp_window;
 
 	PreferencesDialog *pref_dialog;
 	FilePropertiesDialog *file_dialog;
@@ -806,14 +874,16 @@ protected:
 
 	Favorites * favorites;
 
+#ifdef TV_SUPPORT
 	TVList * tvlist;
 	TVList * radiolist;
+#endif
 
 #ifdef UPDATE_CHECKER
 	UpdateChecker * update_checker;
 #endif
 
-#ifdef SHAREWIDGET
+#ifdef SHARE_WIDGET
 	ShareWidget * sharewidget;
 #endif
 
@@ -825,6 +895,11 @@ protected:
 	int arg_close_on_finish; // -1 = not set, 1 = true, 0 = false
 	int arg_start_in_fullscreen; // -1 = not set, 1 = true, 0 = false
 
+#ifdef MG_DELAYED_SEEK
+	QTimer * delayed_seek_timer;
+	int delayed_seek_value;
+#endif
+
 private:
 	QString default_style;
 
@@ -834,12 +909,9 @@ private:
 	QSize win_size;
 	bool was_maximized;
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 #ifdef AVOID_SCREENSAVER
-	/* Disable screensaver by event */
 	bool just_stopped;
 #endif
-#endif
 
 #ifdef LOG_MPLAYER
 	QString mplayer_log;
@@ -850,6 +922,6 @@ private:
 
 	bool ignore_show_hide_events;
 };
-    
+
 #endif
 
