@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,16 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _CONFIG_H_
-#define _CONFIG_H_
+#ifndef CONFIG_H
+#define CONFIG_H
 
 #include <Qt>
 
+#define NOTIFY_SUB_CHANGES 1
+#define NOTIFY_AUDIO_CHANGES 1
+#define NOTIFY_VIDEO_CHANGES 0
+#define NOTIFY_CHAPTER_CHANGES 1
+
 
 // STYLE_SWITCHING
 // if 1, the preferences dialog will have an option to switch
@@ -85,7 +90,7 @@
 
 // Just for testing, possibility to disable the use of the colorkey
 
-#define USE_COLORKEY 1
+#define USE_COLORKEY 0
 
 
 // USE_MINIMUMSIZE
@@ -97,25 +102,32 @@
 
 // DVDNAV_SUPPORT
 // if 1, smplayer will be compiled with support for mplayer's dvdnav
-
+#ifdef MPLAYER_SUPPORT
 #define DVDNAV_SUPPORT 1
+#endif
 
 
 // PROGRAM_SWITCH
 // support for program switch in ts files
 
-#define PROGRAM_SWITCH 1
+#define PROGRAM_SWITCH 0
+
+
+// ALLOW_DEMUXER_CODE_CHANGE
+// support changing of demuxer and video and audio codecs
+
+#define ALLOW_DEMUXER_CODEC_CHANGE 1
 
 
 // Adds or not the "Repaint the background of the video window" option.
-//#ifndef Q_OS_WIN
+#ifndef Q_OS_WIN
 #define REPAINT_BACKGROUND_OPTION 1
-//#endif
+#endif
 
 
 // Enables/disables the use of -adapter
 #ifdef Q_OS_WIN
-#define USE_ADAPTER 1
+#define USE_ADAPTER 0
 #define OVERLAY_VO "directx"
 //#define OVERLAY_VO "xv"
 #endif
@@ -128,12 +140,6 @@
 #endif
 
 
-// If 1, smplayer will add support for the mplayer slave command
-// "panscan".
-
-#define USE_MPLAYER_PANSCAN 0
-
-
 // If 1, the background logo will be animated
 #if QT_VERSION >= 0x040600
 /* #define LOGO_ANIMATION 1 */
