@@ -158,6 +158,11 @@ public slots:
 	void toggleVolnorm();
 	void toggleVolnorm(bool b);
 
+#ifdef MPV_SUPPORT
+	void toggleEarwax();
+	void toggleEarwax(bool b);
+#endif
+
 	void setAudioChannels(int channels);
 	void setStereoMode(int mode);
 
@@ -254,6 +259,10 @@ public slots:
 	void incOSDScale();
 	void decOSDScale();
 
+#ifdef MPV_SUPPORT
+	void setOSDFractions(bool active);
+#endif
+
 	//! Select next line in subtitle file
 	void incSubStep();
 	//! Select previous line in subtitle file
@@ -308,6 +317,8 @@ public slots:
 #ifdef BOOKMARKS
 	void nextBookmark();
 	void prevBookmark();
+
+	void saveBookmarks();
 #endif
 
 	#if 0
