@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _EXTENSIONS_H_
-#define _EXTENSIONS_H_
+#ifndef EXTENSIONS_H
+#define EXTENSIONS_H
 
 #include <QStringList>
 
@@ -27,10 +27,11 @@ public:
 	ExtensionList();
 
 	QString forFilter();
+	QStringList forDirFilter();
 	QString forRegExp();
 };
 
-class Extensions 
+class Extensions
 {
 public:
 	Extensions();
@@ -43,6 +44,8 @@ public:
 	ExtensionList multimedia() { return _multimedia; };
 	ExtensionList allPlayable() { return _all_playable; };
 
+	static QString extensionFromUrl(const QString & url);
+
 protected:
 	ExtensionList _video, _audio, _playlist, _subtitles;
 	ExtensionList _multimedia; //!< video and audio
