@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,6 @@ void MediaSettings::reset() {
 	current_video_id = NoneSelected;
 	current_audio_id = NoneSelected;
 	current_title_id = NoneSelected;
-	current_chapter_id = NoneSelected;
 	current_angle_id = NoneSelected;
 
 	aspect_ratio_id = AspectAuto;
@@ -90,18 +89,29 @@ void MediaSettings::reset() {
 	//current_deinterlacer = NoDeinterlace;
 	current_deinterlacer = pref->initial_deinterlace;
 
+#ifdef INITIAL_BLACKBORDERS
+	add_letterbox = pref->initial_blackborders;
+#else
 	add_letterbox = false;
+#endif
 
-    karaoke_filter = false;
+#ifdef MPLAYER_SUPPORT
+	karaoke_filter = false;
+#endif
 	extrastereo_filter = false;
 	volnorm_filter = pref->initial_volnorm;
+#ifdef MPV_SUPPORT
+	earwax_filter = false;
+#endif
 
 	audio_use_channels = pref->initial_audio_channels; //ChDefault; // (0)
 	stereo_mode = pref->initial_stereo_mode; //Stereo; // (0)
 
 	zoom_factor = pref->initial_zoom_factor; // 1.0;
 
+#ifdef MSET_USE_STARTING_TIME
 	starting_time = -1; // Not set yet.
+#endif
 
 	rotate = NoRotate;
 	flip = false;
@@ -111,6 +121,12 @@ void MediaSettings::reset() {
 	A_marker = -1;
 	B_marker = -1;
 
+#ifdef BOOKMARKS
+	// Initialize bookmarks
+	bookmarks.clear();
+	bookmarks.insert(0, "");
+#endif
+
 	is264andHD = false;
 
 	current_demuxer = "unknown";
@@ -198,7 +214,6 @@ void MediaSettings::list() {
 	qDebug("  current_video_id: %d", current_video_id);
 	qDebug("  current_audio_id: %d", current_audio_id);
 	qDebug("  current_title_id: %d", current_title_id);
-	qDebug("  current_chapter_id: %d", current_chapter_id);
 	qDebug("  current_angle_id: %d", current_angle_id);
 
 	qDebug("  aspect_ratio_id: %d", aspect_ratio_id);
@@ -241,9 +256,14 @@ void MediaSettings::list() {
 
 	qDebug("  add_letterbox: %d", add_letterbox);
 
+#ifdef MPLAYER_SUPPORT
 	qDebug("  karaoke_filter: %d", karaoke_filter);
+#endif
 	qDebug("  extrastereo_filter: %d", extrastereo_filter);
 	qDebug("  volnorm_filter: %d", volnorm_filter);
+#ifdef MPV_SUPPORT
+	qDebug("  earwax_filter: %d", earwax_filter);
+#endif
 
 	qDebug("  audio_use_channels: %d", audio_use_channels);
 	qDebug("  stereo_mode: %d", stereo_mode);
@@ -278,11 +298,13 @@ void MediaSettings::list() {
 	qDebug("  win_height: %d", win_height); 
 	qDebug("  win_aspect(): %f", win_aspect()); 
 
+#ifdef MSET_USE_STARTING_TIME
 	qDebug("  starting_time: %f", starting_time);
+#endif
+
 	qDebug("  is264andHD: %d", is264andHD);
 }
 
-#ifndef NO_USE_INI_FILES
 void MediaSettings::save(QSettings * set, int player_id) {
 	qDebug("MediaSettings::save");
 
@@ -324,7 +346,6 @@ void MediaSettings::save(QSettings * set, int player_id) {
 	set->setValue( "current_sec", current_sec );
 
 	set->setValue( "current_title_id", current_title_id );
-	set->setValue( "current_chapter_id", current_chapter_id );
 	set->setValue( "current_angle_id", current_angle_id );
 
 	set->setValue( "aspect_ratio", aspect_ratio_id );
@@ -369,11 +390,16 @@ void MediaSettings::save(QSettings * set, int player_id) {
 
 	set->setValue( "add_letterbox", add_letterbox );
 
+#ifdef MPLAYER_SUPPORT
 	set->setValue( "karaoke_filter", karaoke_filter);
+#endif
 	set->setValue( "extrastereo_filter", extrastereo_filter);
 	set->setValue( "volnorm_filter", volnorm_filter);
+#ifdef MPV_SUPPORT
+	set->setValue( "earwax_filter", earwax_filter);
+#endif
 
-	set->setValue( "audio_use_channels", audio_use_channels);
+	set->setValue( "audio_channels", audio_use_channels);
 	set->setValue( "stereo_mode", stereo_mode);
 
 	set->setValue( "zoom_factor", zoom_factor);
@@ -386,6 +412,24 @@ void MediaSettings::save(QSettings * set, int player_id) {
 	set->setValue( "A_marker", A_marker);
 	set->setValue( "B_marker", B_marker);
 
+#ifdef BOOKMARKS
+	// Save bookmarks
+	bool save_bookmarks = true;
+	QMap<int, QString>::const_iterator i = bookmarks.constBegin();
+	if (save_bookmarks) {
+		set->beginWriteArray("bookmarks");
+		int count = 0;
+		while (i != bookmarks.constEnd()) {
+			set->setArrayIndex(count);
+			set->setValue("time", i.key());
+			set->setValue("name", i.value());
+			i++;
+			count++;
+		}
+		set->endArray();
+	}
+#endif
+
 	set->setValue( "mplayer_additional_options", mplayer_additional_options);
 	set->setValue( "mplayer_additional_video_filters", mplayer_additional_video_filters);
 	set->setValue( "mplayer_additional_audio_filters", mplayer_additional_audio_filters);
@@ -393,7 +437,9 @@ void MediaSettings::save(QSettings * set, int player_id) {
 	set->setValue( "win_width", win_width );
 	set->setValue( "win_height", win_height );
 
+#ifdef MSET_USE_STARTING_TIME
 	set->setValue( "starting_time", starting_time );
+#endif
 
 	set->setValue( "is264andHD", is264andHD );
 }
@@ -441,7 +487,6 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	current_sec = set->value( "current_sec", current_sec).toDouble();
 
 	current_title_id = set->value( "current_title_id", current_title_id ).toInt();
-	current_chapter_id = set->value( "current_chapter_id", current_chapter_id ).toInt();
 	current_angle_id = set->value( "current_angle_id", current_angle_id ).toInt();
 
 	aspect_ratio_id = set->value( "aspect_ratio", aspect_ratio_id ).toInt();
@@ -486,11 +531,16 @@ void MediaSettings::load(QSettings * set, int player_id) {
 
 	add_letterbox = set->value( "add_letterbox", add_letterbox ).toBool();
 
+#ifdef MPLAYER_SUPPORT
 	karaoke_filter = set->value( "karaoke_filter", karaoke_filter).toBool();
+#endif
 	extrastereo_filter = set->value( "extrastereo_filter", extrastereo_filter).toBool();
 	volnorm_filter = set->value( "volnorm_filter", volnorm_filter).toBool();
+#ifdef MPV_SUPPORT
+	earwax_filter = set->value( "earwax_filter", earwax_filter).toBool();
+#endif
 
-	audio_use_channels = set->value( "audio_use_channels", audio_use_channels).toInt();
+	audio_use_channels = set->value( "audio_channels", audio_use_channels).toInt();
 	stereo_mode = set->value( "stereo_mode", stereo_mode).toInt();
 
 	zoom_factor = set->value( "zoom_factor", zoom_factor).toDouble();
@@ -503,6 +553,20 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	A_marker = set->value( "A_marker", A_marker).toInt();
 	B_marker = set->value( "B_marker", B_marker).toInt();
 
+#ifdef BOOKMARKS
+	// Load bookmarks
+	int n_bookmarks = set->beginReadArray("bookmarks");
+	if (n_bookmarks > 0) {
+		bookmarks.clear();
+		for (int i = 0; i < n_bookmarks; ++i) {
+			set->setArrayIndex(i);
+			int time = set->value("time").toInt();
+			QString name = set->value("name").toString();
+			bookmarks.insert(time, name);
+		}
+	}
+	set->endArray();
+#endif
 
 	mplayer_additional_options = set->value( "mplayer_additional_options", mplayer_additional_options).toString();
 	mplayer_additional_video_filters = set->value( "mplayer_additional_video_filters", mplayer_additional_video_filters).toString();
@@ -511,12 +575,13 @@ void MediaSettings::load(QSettings * set, int player_id) {
 	win_width = set->value( "win_width", win_width ).toInt();
 	win_height = set->value( "win_height", win_height ).toInt();
 
+#ifdef MSET_USE_STARTING_TIME
 	starting_time = set->value( "starting_time", starting_time ).toDouble();
+#endif
 
 	is264andHD = set->value( "is264andHD", is264andHD ).toBool();
 
 	// ChDefault not used anymore
-	if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
+	//if (audio_use_channels == ChDefault) audio_use_channels = ChStereo;
 }
 
-#endif // NO_USE_INI_FILES
