@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,10 +16,14 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <QDir>
 #include <QDebug>
 #include "inforeader.h"
+#include "deviceinfo.h"
 
-void MPVProcess::addArgument(const QString & a) {
+//#define USE_ANEQUALIZER
+
+void MPVProcess::addArgument(const QString & /*a*/) {
 }
 
 void MPVProcess::setMedia(const QString & media, bool is_playlist) {
@@ -28,24 +32,25 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 			"INFO_VIDEO_WIDTH=${=width}\nINFO_VIDEO_HEIGHT=${=height}\n"
 			"INFO_VIDEO_ASPECT=${=video-aspect}\n"
 //			"INFO_VIDEO_DSIZE=${=dwidth}x${=dheight}\n"
-			"INFO_VIDEO_FPS=${=fps}\n"
+			"INFO_VIDEO_FPS=${=container-fps:${=fps}}\n"
 //			"INFO_VIDEO_BITRATE=${=video-bitrate}\n"
 			"INFO_VIDEO_FORMAT=${=video-format}\n"
 			"INFO_VIDEO_CODEC=${=video-codec}\n"
 
 //			"INFO_AUDIO_BITRATE=${=audio-bitrate}\n"
-//			"INFO_AUDIO_FORMAT=${=audio-format}\n"
-			"INFO_AUDIO_FORMAT=${=audio-codec-name:${=audio-format}}\n"
+//			"INFO_AUDIO_FORMAT=${=audio-format}\n" // old
+			"INFO_AUDIO_FORMAT=${=audio-codec-name}\n"
 			"INFO_AUDIO_CODEC=${=audio-codec}\n"
-//			"INFO_AUDIO_RATE=${=audio-samplerate}\n"
-			"INFO_AUDIO_RATE=${=audio-params/samplerate:${=audio-samplerate}}\n"
-//			"INFO_AUDIO_NCH=${=audio-channels}\n"
-			"INFO_AUDIO_NCH=${=audio-params/channel-count:${=audio-channels}}\n"
+//			"INFO_AUDIO_RATE=${=audio-samplerate}\n" // old
+			"INFO_AUDIO_RATE=${=audio-params/samplerate}\n"
+//			"INFO_AUDIO_NCH=${=audio-channels}\n" // old
+			"INFO_AUDIO_NCH=${=audio-params/channel-count}\n"
 
 //			"INFO_LENGTH=${=length}\n"
 			"INFO_LENGTH=${=duration:${=length}}\n"
 
-			"INFO_DEMUXER=${=demuxer}\n"
+			"INFO_DEMUXER=${=current-demuxer:${=demuxer}}\n"
+			"INFO_SEEKABLE=${=seekable}\n"
 			"INFO_TITLES=${=disc-titles}\n"
 			"INFO_CHAPTERS=${=chapters}\n"
 			"INFO_TRACKS_COUNT=${=track-list/count}\n"
@@ -58,10 +63,15 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 			"METADATA_TRACK=${metadata/by-key/track:}\n"
 			"METADATA_COPYRIGHT=${metadata/by-key/copyright:}\n"
 
-			"INFO_MEDIA_TITLE=${=media-title:}\n";
+			"INFO_MEDIA_TITLE=${=media-title:}\n"
+			"INFO_STREAM_PATH=${stream-path}\n";
+
+#ifndef Q_OS_WIN
+	arg << "--audio-client-name=SMPlayer";
+#endif
 
 #ifdef CUSTOM_STATUS
-	arg << "--term-status-msg=STATUS: ${=time-pos} / ${=duration:${=length:0}} P: ${=pause} B: ${=paused-for-cache} I: ${=core-idle}";
+	arg << "--term-status-msg=STATUS: ${=time-pos} / ${=duration:${=length:0}} P: ${=pause} B: ${=paused-for-cache} I: ${=core-idle} VB: ${=video-bitrate:0} AB: ${=audio-bitrate:0}";
 #endif
 
 	if (is_playlist) {
@@ -69,6 +79,18 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 	} else {
 		arg << media;
 	}
+
+#ifdef CAPTURE_STREAM
+	capturing = false;
+#endif
+
+#ifdef OSD_WITH_TIMER
+	if (!osd_timer) {
+		osd_timer = new QTimer(this);
+		osd_timer->setInterval(500);
+		connect(osd_timer, SIGNAL(timeout()), this, SLOT(displayInfoOnOSD()));
+	}
+#endif
 }
 
 void MPVProcess::setFixedOptions() {
@@ -83,16 +105,28 @@ void MPVProcess::setFixedOptions() {
 
 void MPVProcess::disableInput() {
 	arg << "--no-input-default-bindings";
-	arg << "--input-x11-keyboard=no";
+	if (isOptionAvailable("--input-vo-keyboard")) {
+		arg << "--input-vo-keyboard=no";
+	} else {
+		arg << "--input-x11-keyboard=no";
+	}
 	arg << "--no-input-cursor";
 	arg << "--cursor-autohide=no";
 }
 
 bool MPVProcess::isOptionAvailable(const QString & option) {
-	InfoReader * ir = InfoReader::obj(executable());
-	ir->getInfo();
-	//qDebug() << "MPVProcess::isOptionAvailable: option_list:" << ir->optionList();
-	return ir->optionList().contains(option);
+	static QStringList option_list;
+	static QString mpv_bin;
+
+	if (option_list.isEmpty() || mpv_bin != executable()) {
+		InfoReader * ir = InfoReader::obj(executable());
+		ir->getInfo();
+		option_list = ir->optionList();
+		mpv_bin = executable();
+		//qDebug() << "MPVProcess::isOptionAvailable: option_list:" << option_list;
+	}
+
+	return option_list.contains(option);
 }
 
 void MPVProcess::addVFIfAvailable(const QString & vf, const QString & value) {
@@ -108,6 +142,32 @@ void MPVProcess::addVFIfAvailable(const QString & vf, const QString & value) {
 	}
 }
 
+void MPVProcess::messageFilterNotSupported(const QString & filter_name) {
+	QString text = tr("the '%1' filter is not supported by mpv").arg(filter_name);
+	writeToStdin(QString("show_text \"%1\" 3000").arg(text));
+}
+
+void MPVProcess::enableScreenshots(const QString & dir, const QString & templ, const QString & format) {
+	if (!templ.isEmpty()) {
+		arg << "--screenshot-template=" + templ;
+	}
+
+	if (!format.isEmpty()) {
+		arg << "--screenshot-format=" + format;
+	}
+
+	if (!dir.isEmpty()) {
+		QString d = QDir::toNativeSeparators(dir);
+		if (!isOptionAvailable("--screenshot-directory")) {
+			qDebug() << "MPVProcess::enableScreenshots: the option --screenshot-directory is not available in this version of mpv";
+			qDebug() << "MPVProcess::enableScreenshots: changing working directory to" << d;
+			setWorkingDirectory(d);
+		} else {
+			arg << "--screenshot-directory=" + d;
+		}
+	}
+}
+
 void MPVProcess::setOption(const QString & option_name, const QVariant & value) {
 	if (option_name == "cache") {
 		int cache = value.toInt();
@@ -118,6 +178,10 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		}
 	}
 	else
+	if (option_name == "cache_auto") {
+		arg << "--cache=auto";
+	}
+	else
 	if (option_name == "ss") {
 		arg << "--start=" + value.toString();
 	}
@@ -127,9 +191,11 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	}
 	else
 	if (option_name == "loop") {
+		QString loop = "--loop";
+		if (isOptionAvailable("--loop-file")) loop = "--loop-file";
 		QString o = value.toString();
 		if (o == "0") o = "inf";
-		arg << "--loop=" + o;
+		arg << loop + "=" + o;
 	}
 	else
 	if (option_name == "ass") {
@@ -196,6 +262,18 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		arg << "--sub-scale=" + value.toString();
 	}
 	else
+	if (option_name == "ass-line-spacing") {
+		QString line_spacing = "--ass-line-spacing";
+		if (isOptionAvailable("--sub-ass-line-spacing")) line_spacing = "--sub-ass-line-spacing";
+		arg << line_spacing + "=" + value.toString();
+	}
+	else
+	if (option_name == "ass-force-style") {
+		QString ass_force_style = "--ass-force-style";
+		if (isOptionAvailable("--sub-ass-force-style")) ass_force_style = "--sub-ass-force-style";
+		arg << ass_force_style + "=" + value.toString();
+	}
+	else
 	if (option_name == "stop-xscreensaver") {
 		bool stop_ss = value.toBool();
 		if (stop_ss) arg << "--stop-screensaver"; else arg << "--no-stop-screensaver";
@@ -211,13 +289,20 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	}
 	else
 	if (option_name == "softvol") {
-		arg << "--softvol=yes";
-	}
-	else
-	if (option_name == "softvol-max") {
-		int v = value.toInt();
-		if (v < 100) v = 100;
-		arg << "--softvol-max=" + QString::number(v);
+		if (value.toString() == "off") {
+			if (isOptionAvailable("--volume-max")) {
+				arg << "--volume-max=100";
+			}
+		} else {
+			int v = value.toInt();
+			if (v < 100) v = 100;
+			if (isOptionAvailable("--volume-max")) {
+				arg << "--volume-max=" + QString::number(v);
+			} else {
+				arg << "--softvol=yes";
+				arg << "--softvol-max=" + QString::number(v);
+			}
+		}
 	}
 	else
 	if (option_name == "subfps") {
@@ -249,10 +334,6 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		*/
 	}
 	else
-	if (option_name == "screenshot_template") {
-		arg << "--screenshot-template=" + value.toString();
-	}
-	else
 	if (option_name == "threads") {
 		arg << "--vd-lavc-threads=" + value.toString();
 	}
@@ -266,15 +347,77 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		if (b) arg << "--" + option_name; else arg << "--no-" + option_name;
 	}
 	else
-	if (option_name == "ao") {
-		QString o = value.toString();
-		if (o.startsWith("alsa:device=")) {
-			QString device = o.mid(12);
-			//qDebug() << "MPVProcess::setOption: alsa device:" << device;
-			device = device.replace("=", ":").replace(".", ",");
-			o = "alsa:device=[" + device + "]";
+	if (option_name == "vo") {
+		QString vo = value.toString();
+		if (vo.endsWith(",")) vo.chop(1);
+		#ifndef Q_OS_WIN
+		if (isOptionAvailable("--xv-adaptor")) {
+			QRegExp rx("xv:adaptor=(\\d+)");
+			if (rx.indexIn(vo) > -1) {
+				QString adaptor = rx.cap(1);
+				vo = "xv";
+				arg << "--xv-adaptor=" + adaptor;
+			}
 		}
-		arg << "--ao=" + o;
+		#endif
+
+		// Remove options (used by mplayer)
+		int pos = vo.indexOf(":");
+		if (pos > -1) vo = vo.left(pos);
+
+		if (vo == "gl") vo = "opengl";
+
+		arg << "--vo=" + vo + ",";
+	}
+	else
+	if (option_name == "ao") {
+		QString ao = value.toString();
+
+		QStringList l;
+		if (ao.contains(":")) l = DeviceInfo::extractDevice(ao);
+		if (l.count() > 0) ao = l[0];
+
+		if (isOptionAvailable("--audio-device")) {
+			if (l.count() == 3) {
+				#ifndef Q_OS_WIN
+				if (l[0] == "pulse") {
+					arg << "--audio-device=pulse/" + l[2];
+				}
+				#if USE_MPV_ALSA_DEVICES
+				else
+				if (l[0] == "alsa") {
+					arg << "--audio-device=alsa/" + l[1];
+				}
+				#endif
+				#else
+				if (l[0] == "dsound") {
+					arg << "--audio-device=dsound/" + l[1];
+				}
+				else
+				if (l[0] == "wasapi") {
+					arg << "--audio-device=wasapi/" + l[1];
+				}
+				#endif
+			}
+		} else {
+			#ifndef Q_OS_WIN
+			if (l.count() > 1) {
+				if (l[0] == "alsa") {
+					ao = "alsa:device=[hw:" + l[1] + "]";
+				}
+				else
+				if (l[0] == "pulse") {
+					ao = "pulse::" + l[1];
+				}
+			}
+			#endif
+		}
+
+		// Remove options (used by mplayer)
+		int pos = ao.indexOf(":");
+		if (pos > -1) ao = ao.left(pos);
+
+		arg << "--ao=" + ao + ",";
 	}
 	else
 	if (option_name == "vc") {
@@ -308,6 +451,17 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 		verbose = true;
 	}
 	else
+	if (option_name == "mute") {
+		arg << "--mute=yes";
+	}
+	else
+	if (option_name == "scaletempo") {
+		if (isOptionAvailable("--audio-pitch-correction")) {
+			bool enabled = value.toBool();
+			if (enabled) arg << "--audio-pitch-correction=yes"; else arg << "--audio-pitch-correction=no";
+		}
+	}
+	else
 	if (option_name == "vf-add") {
 		if (!value.isNull()) arg << "--vf-add=" + value.toString();
 	}
@@ -317,11 +471,9 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	}
 	else
 	if (option_name == "wid" ||
-	    option_name == "vo" ||
 	    option_name == "aid" || option_name == "vid" ||
 	    option_name == "volume" ||
-	    option_name == "ass-styles" || option_name == "ass-force-style" ||
-	    option_name == "ass-line-spacing" ||
+	    option_name == "ass-styles" ||
 	    option_name == "embeddedfonts" ||
 	    option_name == "osd-scale" ||
 	    option_name == "speed" ||
@@ -335,7 +487,9 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	    option_name == "autosync" ||
 	    option_name == "dvd-device" || option_name == "cdrom-device" ||
 	    option_name == "demuxer" ||
-	    option_name == "frames")
+	    option_name == "frames" ||
+	    option_name == "user-agent" || option_name == "referrer" ||
+	    option_name == "ab-loop-a" || option_name == "ab-loop-b")
 	{
 		QString s = "--" + option_name;
 		if (!value.isNull()) s += "=" + value.toString();
@@ -348,12 +502,35 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 }
 
 void MPVProcess::addUserOption(const QString & option) {
-	arg << option;
+	qDebug() << "MPVProcess::addUserOption:" << option;
+
+	// Remove quotes
+	QString s = option;
+	if (s.count("=\"") == 1 && s.endsWith("\"")) {
+		s.replace("=\"", "=");
+		s.chop(1);
+	}
+	else
+	if (s.startsWith("\"") && s.endsWith("\"")) {
+		s.remove(0, 1);
+		s.chop(1);
+	}
+
+	qDebug() << "MPVProcess::addUserOption: s:" << s;
+
+	arg << s;
 	if (option == "-v") {
 		verbose = true;
 	}
 }
 
+void MPVProcess::setSubEncoding(const QString & codepage, const QString & enca_lang) {
+	Q_UNUSED(enca_lang)
+	if (!codepage.isEmpty()) {
+		arg << "--sub-codepage=" + codepage;
+	}
+}
+
 void MPVProcess::addVF(const QString & filter_name, const QVariant & value) {
 	QString option = value.toString();
 
@@ -419,10 +596,6 @@ void MPVProcess::addVF(const QString & filter_name, const QVariant & value) {
 		// Ignore
 	}
 	else
-	if (filter_name == "screenshot") {
-		//arg << "--screenshot-template=%{filename:shot}-%p-%04n";
-	}
-	else
 	if (filter_name == "rotate") {
 		if (option == "0") {
 			arg << "--vf-add=rotate=270,flip";
@@ -461,9 +634,9 @@ void MPVProcess::addAF(const QString & filter_name, const QVariant & value) {
 	QString option = value.toString();
 
 	if (filter_name == "volnorm") {
-		QString s = "drc";
+		QString s = "acompressor";
 		if (!option.isEmpty()) s += "=" + option;
-		arg << "--af-add=" + s;
+		arg << "--af-add=lavfi=[" + s + "]";
 	}
 	else
 	if (filter_name == "channels") {
@@ -481,8 +654,29 @@ void MPVProcess::addAF(const QString & filter_name, const QVariant & value) {
 	}
 	else
 	if (filter_name == "equalizer") {
+		AudioEqualizerList l = value.toList();
+		#ifndef USE_ANEQUALIZER
+		option = Helper::equalizerListToString(l);
 		previous_eq = option;
 		arg << "--af-add=equalizer=" + option;
+		#else
+		option = Helper::equalizerListToString(l, true);
+		previous_eq = option;
+		arg << "--af-add=lavfi=[anequalizer=" + option + "]";
+		#endif
+	}
+	else
+	if (filter_name == "extrastereo") {
+		arg << "--af-add=lavfi=[extrastereo]";
+	}
+	else
+	if (filter_name == "earwax") {
+		arg << "--af-add=lavfi=[earwax]";
+	}
+	else
+	if (filter_name == "karaoke") {
+		/* Not supported anymore */
+		/* Ignore */
 	}
 	else {
 		QString s = filter_name;
@@ -511,7 +705,7 @@ void MPVProcess::setVideo(int ID) {
 	writeToStdin("set vid " + QString::number(ID));
 }
 
-void MPVProcess::setSubtitle(int type, int ID) {
+void MPVProcess::setSubtitle(int /*type*/, int ID) {
 	writeToStdin("set sid " + QString::number(ID));
 }
 
@@ -564,13 +758,68 @@ void MPVProcess::showOSDText(const QString & text, int duration, int level) {
 }
 
 void MPVProcess::showFilenameOnOSD() {
-	writeToStdin("show_text \"${filename}\" 2000 0");
+#ifdef OSD_WITH_TIMER
+	toggleInfoOnOSD();
+#else
+	showOSDText("${filename}", 2000, 0);
+#endif
 }
 
 void MPVProcess::showTimeOnOSD() {
-	writeToStdin("show_text \"${time-pos} / ${length:0} (${percent-pos}%)\" 2000 0");
+#ifdef OSD_WITH_TIMER
+	osd_timer->stop();
+#endif
+	writeToStdin("show_text \"${time-pos} ${?duration:/ ${duration} (${percent-pos}%)}\" 2000 0");
 }
 
+#ifdef OSD_WITH_TIMER
+void MPVProcess::toggleInfoOnOSD() {
+	if (!osd_timer->isActive()) {
+		osd_timer->start();
+		displayInfoOnOSD();
+	} else {
+		osd_timer->stop();
+		showOSDText("", 100, 0);
+	}
+}
+
+void MPVProcess::displayInfoOnOSD() {
+	QString b1 = "{\\\\b1}";
+	QString b0 = "{\\\\b0}";
+	QString tab = "\\\\h\\\\h\\\\h\\\\h\\\\h";
+	QString nl = "\\n";
+
+	QString s = "${osd-ass-cc/0}{\\\\fs14}" +
+		b1 + tr("File:") + b0 +" ${filename}" + nl +
+		"${time-pos} ${?duration:/ ${duration} (${percent-pos}%)}" + nl + nl +
+		//b1 + tr("Title:") + b0 + " ${media-title}" + nl + nl +
+		b1 + tr("Video:") + b0 + " ${video-codec}" + nl +
+		tab + b1 + tr("Resolution:") + b0 +" ${=width}x${=height}" + nl +
+		tab + b1 + tr("Frames per second:") + b0 + " ${container-fps:${fps}} " + b1 + tr("Estimated:") + b0 + " ${estimated-vf-fps}" + nl +
+		//tab + b1 + tr("Display FPS:") + b0 + " ${display-fps}" + nl +
+		tab + b1 + tr("Aspect Ratio:") + b0 + " ${video-params/aspect}" + nl +
+		tab + b1 + tr("Bitrate:") + b0 + " ${video-bitrate}" + nl +
+		tab + b1 + tr("Dropped frames:") + b0 + " ${decoder-frame-drop-count:${drop-frame-count}}" + nl +
+		nl +
+
+		b1 + tr("Audio:") + b0 + " ${audio-codec}" + nl + 
+		tab + b1 + tr("Bitrate:") + b0 + " ${audio-bitrate}" + nl +
+		tab + b1 + tr("Sample Rate:") + b0 + " ${audio-params/samplerate} Hz" + nl +
+		tab + b1 + tr("Channels:") + b0 + " ${audio-params/channel-count}" + nl +
+		nl +
+
+		b1 + tr("Audio/video synchronization:") + b0 + " ${avsync}" + nl +
+		b1 + tr("Cache fill:") + b0 + " ${cache:0}%" + nl +
+		b1 + tr("Used cache:") + b0 + " ${cache-used:0}" + nl;
+
+	if (!osd_media_info.isEmpty()) s = osd_media_info;
+
+	showOSDText(s, 2000, 0);
+
+	if (!isRunning()) osd_timer->stop();
+}
+#endif
+
 void MPVProcess::setContrast(int value) {
 	writeToStdin("set contrast " + QString::number(value));
 }
@@ -595,6 +844,14 @@ void MPVProcess::setChapter(int ID) {
 	writeToStdin("set chapter " + QString::number(ID));
 }
 
+void MPVProcess::nextChapter() {
+	writeToStdin("add chapter 1");
+}
+
+void MPVProcess::previousChapter() {
+	writeToStdin("add chapter -1");
+}
+
 void MPVProcess::setExternalSubtitleFile(const QString & filename) {
 	writeToStdin("sub_add \""+ filename +"\"");
 	//writeToStdin("print_text ${track-list}");
@@ -613,6 +870,10 @@ void MPVProcess::setSubStep(int value) {
 	writeToStdin("sub_step " + QString::number(value));
 }
 
+void MPVProcess::seekSub(int value) {
+	writeToStdin("sub-seek " + QString::number(value));
+}
+
 void MPVProcess::setSubForcedOnly(bool b) {
 	writeToStdin(QString("set sub-forced-only %1").arg(b ? "yes" : "no"));
 }
@@ -621,19 +882,32 @@ void MPVProcess::setSpeed(double value) {
 	writeToStdin("set speed " + QString::number(value));
 }
 
-void MPVProcess::enableKaraoke(bool b) {
+#ifdef MPLAYER_SUPPORT
+void MPVProcess::enableKaraoke(bool /*b*/) {
+	/*
 	if (b) writeToStdin("af add karaoke"); else writeToStdin("af del karaoke");
+	*/
+	messageFilterNotSupported("karaoke");
 }
+#endif
 
 void MPVProcess::enableExtrastereo(bool b) {
-	if (b) writeToStdin("af add extrastereo"); else writeToStdin("af del extrastereo");
+	if (b) writeToStdin("af add lavfi=[extrastereo]"); else writeToStdin("af del lavfi=[extrastereo]");
 }
 
 void MPVProcess::enableVolnorm(bool b, const QString & option) {
-	if (b) writeToStdin("af add drc=" + option); else writeToStdin("af del drc=" + option);
+	QString s = "acompressor";
+	if (!option.isEmpty()) s += "=" + option;
+	if (b) writeToStdin("af add lavfi=[" + s + "]"); else writeToStdin("af del lavfi=[" + s + "]");
 }
 
-void MPVProcess::setAudioEqualizer(const QString & values) {
+void MPVProcess::enableEarwax(bool b) {
+	if (b) writeToStdin("af add lavfi=[earwax]"); else writeToStdin("af del lavfi=[earwax]");
+}
+
+void MPVProcess::setAudioEqualizer(AudioEqualizerList l) {
+#ifndef USE_ANEQUALIZER
+	QString values = Helper::equalizerListToString(l);
 	if (values == previous_eq) return;
 
 	if (!previous_eq.isEmpty()) {
@@ -641,6 +915,19 @@ void MPVProcess::setAudioEqualizer(const QString & values) {
 	}
 	writeToStdin("af add equalizer=" + values);
 	previous_eq = values;
+#else
+	/* Not working */
+	#if 0
+	QString values = Helper::equalizerListToString(l, true);
+	if (values == previous_eq) return;
+
+	if (!previous_eq.isEmpty()) {
+		writeToStdin("af del lavfi=[anequalizer=" + previous_eq + "]");
+	}
+	writeToStdin("af add lavfi=[anequalizer=" + values + "]");
+	previous_eq = values;
+	#endif
+#endif
 }
 
 void MPVProcess::setAudioDelay(double delay) {
@@ -658,13 +945,44 @@ void MPVProcess::setLoop(int v) {
 		case 0: o = "inf"; break;
 		default: o = QString::number(v);
 	}
-	writeToStdin(QString("set loop %1").arg(o));
+	writeToStdin(QString("set loop-file %1").arg(o));
+}
+
+void MPVProcess::setAMarker(int sec) {
+	writeToStdin(QString("set ab-loop-a %1").arg(sec));
+}
+
+void MPVProcess::setBMarker(int sec) {
+	writeToStdin(QString("set ab-loop-b %1").arg(sec));
+}
+
+void MPVProcess::clearABMarkers() {
+	writeToStdin("set ab-loop-a no");
+	writeToStdin("set ab-loop-b no");
 }
 
 void MPVProcess::takeScreenshot(ScreenshotType t, bool include_subtitles) {
 	writeToStdin(QString("screenshot %1 %2").arg(include_subtitles ? "subtitles" : "video").arg(t == Single ? "single" : "each-frame"));
 }
 
+#ifdef CAPTURE_STREAM
+void MPVProcess::switchCapturing() {
+	if (!capture_filename.isEmpty()) {
+		if (!capturing) {
+			QString f = capture_filename;
+			#ifdef Q_OS_WIN
+			// I hate Windows
+			f = f.replace("\\", "\\\\");
+			#endif
+			writeToStdin("set stream-capture \"" + f + "\"");
+		} else {
+			writeToStdin("set stream-capture \"\"");
+		}
+		capturing = !capturing;
+	}
+}
+#endif
+
 void MPVProcess::setTitle(int ID) {
 	writeToStdin("set disc-title " + QString::number(ID));
 }
@@ -714,6 +1032,10 @@ void MPVProcess::setOSDScale(double value) {
 	writeToStdin("set osd-scale " + QString::number(value));
 }
 
+void MPVProcess::setOSDFractions(bool active) {
+	writeToStdin(QString("no-osd set osd-fractions %1").arg(active ? "yes" : "no"));
+}
+
 void MPVProcess::changeVF(const QString & filter, bool enable, const QVariant & option) {
 	qDebug() << "MPVProcess::changeVF:" << filter << enable;
 
@@ -814,21 +1136,80 @@ void MPVProcess::changeStereo3DFilter(bool enable, const QString & in, const QSt
 	writeToStdin(QString("vf %1 \"%2\"").arg(enable ? "add" : "del").arg(filter));
 }
 
+#if 0
+
+#define SUBOPTION(name, alternative1, alternative2) \
+	QString name = alternative2;
+
+#else
+
+#define SUBOPTION(name, alternative1, alternative2) \
+	QString name; \
+	if (isOptionAvailable(alternative1)) name = alternative1; \
+	else \
+	if (isOptionAvailable(alternative2)) name = alternative2;
+
+#endif
+
 void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
-	QString font = styles.fontname;
-	//arg << "--sub-text-font=" + font.replace(" ", "");
-	arg << "--sub-text-font=" + font;
-	arg << "--sub-text-color=#" + ColorUtils::colorToRRGGBB(styles.primarycolor);
+	SUBOPTION(sub_font, "--sub-font", "--sub-text-font");
+	SUBOPTION(sub_color, "--sub-color", "--sub-text-color");
+
+	QString sub_shadow_color = "--sub-text-shadow-color";
+	if (isOptionAvailable("--sub-shadow-color")) sub_shadow_color = "--sub-shadow-color";
+
+	QString sub_back_color = "--sub-text-back-color";
+	if (isOptionAvailable("--sub-back-color")) sub_back_color = "--sub-back-color";
+
+	SUBOPTION(sub_border_color, "--sub-border-color", "--sub-text-border-color");
+	SUBOPTION(sub_border_size, "--sub-border-size", "--sub-text-border-size");
+	SUBOPTION(sub_shadow_offset, "--sub-shadow-offset", "--sub-text-shadow-offset");
+
+	SUBOPTION(sub_font_size, "--sub-font-size", "--sub-text-font-size");
+	SUBOPTION(sub_bold, "--sub-bold", "--sub-text-bold");
+	SUBOPTION(sub_italic, "--sub-italic", "--sub-text-italic");
+	SUBOPTION(sub_align_x, "--sub-align-x", "--sub-text-align-x");
+	SUBOPTION(sub_align_y, "--sub-align-y", "--sub-text-align-y");
+
+	if (!sub_font.isEmpty()) {
+		QString font = styles.fontname;
+		//arg << "--sub-text-font=" + font.replace(" ", "");
+		arg << sub_font + "=" + font;
+	}
+
+	if (!sub_color.isEmpty()) {
+		arg << sub_color + "=#" + ColorUtils::colorToAARRGGBB(styles.primarycolor);
+	}
 
 	if (styles.borderstyle == AssStyles::Outline) {
-		arg << "--sub-text-shadow-color=#" + ColorUtils::colorToRRGGBB(styles.backcolor);
+		arg << sub_shadow_color + "=#" + ColorUtils::colorToAARRGGBB(styles.backcolor);
 	} else {
-		arg << "--sub-text-back-color=#" + ColorUtils::colorToRRGGBB(styles.outlinecolor);
+		arg << sub_back_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
 	}
-	arg << "--sub-text-border-color=#" + ColorUtils::colorToRRGGBB(styles.outlinecolor);
 
-	arg << "--sub-text-border-size=" + QString::number(styles.outline * 2.5);
-	arg << "--sub-text-shadow-offset=" + QString::number(styles.shadow * 2.5);
+	if (!sub_border_color.isEmpty()) {
+		arg << sub_border_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
+	}
+
+	if (!sub_border_size.isEmpty()) {
+		arg << sub_border_size + "=" + QString::number(styles.outline * 2.5);
+	}
+
+	if (!sub_shadow_offset.isEmpty()) {
+		arg << sub_shadow_offset + "=" + QString::number(styles.shadow * 2.5);
+	}
+
+	if (!sub_font_size.isEmpty()) {
+		arg << sub_font_size + "=" + QString::number(styles.fontsize * 2.5);
+	}
+
+	if (!sub_bold.isEmpty()) {
+		arg << QString("%1=%2").arg(sub_bold).arg(styles.bold ? "yes" : "no");
+	}
+
+	if (!sub_italic.isEmpty()) {
+		arg << QString("%1=%2").arg(sub_italic).arg(styles.italic ? "yes" : "no");
+	}
 
 	QString halign;
 	switch (styles.halignment) {
@@ -842,11 +1223,12 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 		case AssStyles::Top: valign = "top"; break;
 	}
 
-	if (!halign.isEmpty() || !valign.isEmpty()) {
-		if (isOptionAvailable("--sub-text-align-x")) {
-			if (!halign.isEmpty()) arg << "--sub-text-align-x=" + halign;
-			if (!valign.isEmpty()) arg << "--sub-text-align-y=" + valign;
-		}
+	if (!sub_align_x.isEmpty() && !halign.isEmpty()) {
+		arg << sub_align_x + "=" + halign;
+	}
+	
+	if (!sub_align_y.isEmpty() && !valign.isEmpty()) {
+		arg << sub_align_y + "=" + valign;
 	}
 }
 
