@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,7 +45,10 @@
 #include "retrieveyoutubeurl.h"
 #endif
 
+//#define USE_CONFIG_VERSION
+#ifdef USE_CONFIG_VERSION
 #define CURRENT_CONFIG_VERSION 4
+#endif
 
 using namespace Global;
 
@@ -56,15 +59,11 @@ Preferences::Preferences() {
 
 	reset();
 
-#ifndef NO_USE_INI_FILES
 	load();
-#endif
 }
 
 Preferences::~Preferences() {
-#ifndef NO_USE_INI_FILES
 	save();
-#endif
 
 	delete history_recents;
 	delete history_urls;
@@ -76,20 +75,27 @@ void Preferences::reset() {
        General
        ******* */
 
+#ifdef USE_CONFIG_VERSION
 	config_version = CURRENT_CONFIG_VERSION;
-
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-	mplayer_bin= "mplayer/mplayer.exe";
-#else
-	mplayer_bin = "mplayer";
 #endif
 
-	vo = ""; 
-	ao = "";
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+	mplayer_bin= "mpv/mpv.exe";
+	if (QSysInfo::WindowsVersion < QSysInfo::WV_VISTA) {
+		mplayer_bin= "mplayer/mplayer.exe";
+	}
+#else
+	//mplayer_bin = "mplayer";
+	mplayer_bin = "mpv";
+#endif
+
+	vo = "player_default"; 
+	ao = "player_default";
 
 	use_screenshot = true;
 #ifdef MPV_SUPPORT
 	screenshot_template = "cap_%F_%p_%02n";
+	screenshot_format = "jpg";
 #endif
 	screenshot_directory="";
 #ifdef PORTABLE_APP
@@ -103,8 +109,13 @@ void Preferences::reset() {
 	#endif
 #endif
 
-	dont_remember_media_settings = false;
-	dont_remember_time_pos = false;
+#ifdef CAPTURE_STREAM
+	capture_directory = "";
+#endif
+
+	remember_media_settings = true;
+	remember_time_pos = true;
+	remember_stream_settings = true;
 
 	audio_lang = "";
 	subtitle_lang = "";
@@ -115,9 +126,12 @@ void Preferences::reset() {
 	use_soft_video_eq = false;
 	use_slices = false;
 	autoq = 6;
-	add_blackborders_on_fullscreen = false;
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef ADD_BLACKBORDERS_FS
+	add_blackborders_on_fullscreen = false;
+#endif
+
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	turn_screensaver_off = false;
 	#endif
@@ -134,6 +148,7 @@ void Preferences::reset() {
 	vdpau.ffwmv3vdpau = true;
 	vdpau.ffvc1vdpau = true;
 	vdpau.ffodivxvdpau = false;
+	vdpau.ffhevcvdpau = false;
 	vdpau.disable_video_filters = true;
 #endif
 
@@ -163,13 +178,20 @@ void Preferences::reset() {
 	autoload_m4a = true;
 	min_step = 4;
 
-	osd = None;
+	osd = Seek;
 	osd_scale = 1;
 	subfont_osd_scale = 3;
 	osd_delay = 2200;
+#ifdef MPV_SUPPORT
+	osd_fractions = false;
+#endif
 
 	file_settings_method = "hash"; // Possible values: normal & hash
 
+	tablet_mode = false;
+	#ifdef Q_OS_WIN
+	tablet_mode_change_answer = "";
+	#endif
 
     /* ***************
        Drives (CD/DVD)
@@ -202,15 +224,20 @@ void Preferences::reset() {
        Performance
        *********** */
 
-	priority = AboveNormal; // Option only for windows
+#ifdef Q_OS_WIN
+	priority = Normal;
+#endif
 	frame_drop = false;
 	hard_frame_drop = false;
 	coreavc = false;
 	h264_skip_loop_filter = LoopEnabled;
 	HD_height = 720;
 
+#ifdef OBSOLETE_FAST_AUDIO_CHANGE
 	// MPlayer 1.0rc1 require restart, new versions don't
 	fast_audio_change = Detect;
+#endif
+
 #if !SMART_DVD_CHAPTERS
 	fast_chapter_change = false;
 #endif
@@ -218,23 +245,14 @@ void Preferences::reset() {
 	threads = 1;
 	hwdec = "no";
 
+	cache_auto = true;
 	cache_for_files = 2048;
 	cache_for_streams = 2048;
 	cache_for_dvds = 0; // not recommended to use cache for dvds
 	cache_for_vcds = 1024;
 	cache_for_audiocds = 1024;
+#ifdef TV_SUPPORT
 	cache_for_tv = 3000;
-
-#ifdef YOUTUBE_SUPPORT
-	enable_yt_support = true;
-	yt_quality = RetrieveYoutubeUrl::MP4_720p;
-	//yt_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1";
-	yt_user_agent = "";
-	yt_use_https_main = false;
-	yt_use_https_vi = false;
-#endif
-#ifdef MPV_SUPPORT
-	enable_streaming_sites = false;
 #endif
 
 
@@ -270,7 +288,7 @@ void Preferences::reset() {
 	user_forced_ass_style.clear();
 
 	freetype_support = true;
-#ifdef Q_OS_WIN
+#ifdef FONTS_HACK
 	use_windowsfontdir = false;
 #endif
 
@@ -295,7 +313,7 @@ void Preferences::reset() {
 	use_lavf_demuxer = false;
 
 	mplayer_additional_options="";
-	#ifdef PORTABLE_APP
+	#if defined(PORTABLE_APP) && defined(FONTS_HACK)
 	mplayer_additional_options="-nofontconfig";
 	#endif
     mplayer_additional_video_filters="";
@@ -316,7 +334,10 @@ void Preferences::reset() {
 #if REPAINT_BACKGROUND_OPTION
 	// "Repaint video background" in the preferences dialog
 	#ifndef Q_OS_WIN
-	repaint_video_background = false;
+	// Note: on linux there could be flickering when using mplayer if this option is true
+	// but setting it to false could display a corrupted window
+	// from the moment the user press play until playback actually starts
+	repaint_video_background = true;
 	#else
 	repaint_video_background = true;
 	#endif
@@ -324,6 +345,10 @@ void Preferences::reset() {
 
 	use_edl_files = true;
 
+#ifdef MPLAYER_SUPPORT
+	use_playlist_option = false;
+#endif
+
 	prefer_ipv4 = true;
 
 	use_short_pathnames = false;
@@ -344,6 +369,13 @@ void Preferences::reset() {
 	use_mpris2 = true;
 #endif
 
+#ifdef MPV_SUPPORT
+	mpv_osd_media_info = "";
+#endif
+#ifdef MPLAYER_SUPPORT
+	mplayer_osd_media_info = "";
+#endif
+
 
     /* *********
        GUI stuff
@@ -358,11 +390,19 @@ void Preferences::reset() {
 	resize_method = Never;
 
 #if STYLE_SWITCHING
+	#if QT_VERSION >= 0x050000
+	style = "Fusion";
+	#else
 	style="";
+	#endif
 #endif
 
-	move_when_dragging = true;
+	center_window = false;
+	center_window_if_outside = false;
 
+#ifdef GLOBALSHORTCUTS
+	use_global_shortcuts = false;
+#endif
 
 #if DVDNAV_SUPPORT
 	mouse_left_click_function = "dvdnav_mouse";
@@ -378,6 +418,8 @@ void Preferences::reset() {
 	wheel_function_cycle = Seeking | Volume | Zoom | ChangeSpeed;
 	wheel_function_seeking_reverse = false;
 
+	drag_function = MoveWindow;
+
 	seeking1 = 10;
 	seeking2 = 60;
 	seeking3 = 10*60;
@@ -449,17 +491,31 @@ void Preferences::reset() {
     /* ********
        TV (dvb)
        ******** */
-
+#ifdef TV_SUPPORT
 	check_channels_conf_on_startup = true;
 	initial_tv_deinterlace = MediaSettings::Yadif_1;
 	last_dvb_channel = "";
 	last_tv_channel = "";
+#endif
 
 
     /* ********
        Network
        ******** */
 
+#ifdef MPV_SUPPORT
+	streaming_type = StreamingAuto;
+#else
+	streaming_type = StreamingYT;
+#endif
+#ifdef YOUTUBE_SUPPORT
+	yt_quality = RetrieveYoutubeUrl::MP4_720p;
+	//yt_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1";
+	yt_user_agent = "";
+	yt_use_https_main = false;
+	yt_use_https_vi = false;
+#endif
+
 	// Proxy
 	use_proxy = false;
 	proxy_type = QNetworkProxy::HttpProxy;
@@ -495,6 +551,10 @@ void Preferences::reset() {
 	initial_zoom_factor = 1.0;
 	initial_sub_pos = 100; // 100%
 
+#ifdef INITIAL_BLACKBORDERS
+	initial_blackborders = false;
+#endif
+
 	initial_postprocessing = false;
 	initial_volnorm = false;
 
@@ -513,8 +573,10 @@ void Preferences::reset() {
 
 	mplayer_detected_version = -1; //None version parsed yet
 	mplayer_user_supplied_version = -1;
+#ifdef MPLAYER2_SUPPORT
 	mplayer_is_mplayer2 = false;
 	mplayer2_detected_version = QString::null;
+#endif
 
 
     /* *********
@@ -530,7 +592,7 @@ void Preferences::reset() {
        **************** */
 
 	floating_control_margin = 0;
-	floating_control_width = 70; //70 %
+	floating_control_width = 100; //100%
 	floating_control_animated = true;
 	floating_display_in_compact_mode = false;
 	floating_activation_area = AutohideWidget::Anywhere;
@@ -565,7 +627,6 @@ void Preferences::reset() {
 #endif
 }
 
-#ifndef NO_USE_INI_FILES
 void Preferences::save() {
 	qDebug("Preferences::save");
 
@@ -587,6 +648,7 @@ void Preferences::save() {
 	set->setValue("use_screenshot", use_screenshot);
 	#ifdef MPV_SUPPORT
 	set->setValue("screenshot_template", screenshot_template);
+	set->setValue("screenshot_format", screenshot_format);
 	#endif
 	#if QT_VERSION >= 0x040400
 	set->setValue("screenshot_folder", screenshot_directory);
@@ -594,8 +656,13 @@ void Preferences::save() {
 	set->setValue("screenshot_directory", screenshot_directory);
 	#endif
 
-	set->setValue("dont_remember_media_settings", dont_remember_media_settings);
-	set->setValue("dont_remember_time_pos", dont_remember_time_pos);
+	#ifdef CAPTURE_STREAM
+	set->setValue("capture_directory", capture_directory);
+	#endif
+
+	set->setValue("remember_media_settings", remember_media_settings);
+	set->setValue("remember_time_pos", remember_time_pos);
+	set->setValue("remember_stream_settings", remember_stream_settings);
 
 	set->setValue("audio_lang", audio_lang);
 	set->setValue("subtitle_lang", subtitle_lang);
@@ -605,9 +672,12 @@ void Preferences::save() {
 	set->setValue("use_soft_video_eq", use_soft_video_eq);
 	set->setValue("use_slices", use_slices );
 	set->setValue("autoq", autoq);
-	set->setValue("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen);
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef ADD_BLACKBORDERS_FS
+	set->setValue("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen);
+#endif
+
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	set->setValue("turn_screensaver_off", turn_screensaver_off);
 	#endif
@@ -624,6 +694,7 @@ void Preferences::save() {
 	set->setValue("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau);
 	set->setValue("vdpau_ffvc1vdpau", vdpau.ffvc1vdpau);
 	set->setValue("vdpau_ffodivxvdpau", vdpau.ffodivxvdpau);
+	set->setValue("vdpau_ffhevcvdpau", vdpau.ffhevcvdpau);
 	set->setValue("vdpau_disable_video_filters", vdpau.disable_video_filters);
 #endif
 
@@ -653,9 +724,17 @@ void Preferences::save() {
 	set->setValue("osd_scale", osd_scale);
 	set->setValue("subfont_osd_scale", subfont_osd_scale);
 	set->setValue("osd_delay", osd_delay);
+#ifdef MPV_SUPPORT
+	set->setValue("osd_fractions", osd_fractions);
+#endif
 
 	set->setValue("file_settings_method", file_settings_method);
 
+	set->setValue("tablet_mode", tablet_mode);
+	#ifdef Q_OS_WIN
+	set->setValue("tablet_mode_change_answer", tablet_mode_change_answer);
+	#endif
+
 	set->endGroup(); // General
 
 
@@ -690,14 +769,19 @@ void Preferences::save() {
 
 	set->beginGroup( "performance");
 
+#ifdef Q_OS_WIN
 	set->setValue("priority", priority);
+#endif
 	set->setValue("frame_drop", frame_drop);
 	set->setValue("hard_frame_drop", hard_frame_drop);
 	set->setValue("coreavc", coreavc);
 	set->setValue("h264_skip_loop_filter", h264_skip_loop_filter);
 	set->setValue("HD_height", HD_height);
 
+#ifdef OBSOLETE_FAST_AUDIO_CHANGE
 	set->setValue("fast_audio_change", fast_audio_change);
+#endif
+
 #if !SMART_DVD_CHAPTERS
 	set->setValue("fast_chapter_change", fast_chapter_change);
 #endif
@@ -705,32 +789,18 @@ void Preferences::save() {
 	set->setValue("threads", threads);
 	set->setValue("hwdec", hwdec);
 
+	set->setValue("cache_auto", cache_auto);
 	set->setValue("cache_for_files", cache_for_files);
 	set->setValue("cache_for_streams", cache_for_streams);
 	set->setValue("cache_for_dvds", cache_for_dvds);
 	set->setValue("cache_for_vcds", cache_for_vcds);
 	set->setValue("cache_for_audiocds", cache_for_audiocds);
+#ifdef TV_SUPPORT
 	set->setValue("cache_for_tv", cache_for_tv);
+#endif
 
 	set->endGroup(); // performance
 
-#ifdef YOUTUBE_SUPPORT
-	set->beginGroup("youtube");
-	set->setValue("enable_yt_support", enable_yt_support);
-	set->setValue("quality", yt_quality);
-	set->setValue("user_agent", yt_user_agent);
-	set->setValue("yt_use_https_main", yt_use_https_main);
-	set->setValue("yt_use_https_vi", yt_use_https_vi);
-	set->endGroup();
-#endif
-
-#ifdef MPV_SUPPORT
-	set->beginGroup("streaming");
-	set->setValue("enable_streaming_sites", enable_streaming_sites);
-	set->endGroup();
-#endif
-
-
 
     /* *********
        Subtitles
@@ -763,7 +833,7 @@ void Preferences::save() {
 	set->setValue("user_forced_ass_style", user_forced_ass_style);
 
 	set->setValue("freetype_support", freetype_support);
-#ifdef Q_OS_WIN
+#ifdef FONTS_HACK
 	set->setValue("use_windowsfontdir", use_windowsfontdir);
 #endif
 
@@ -813,6 +883,10 @@ void Preferences::save() {
 
 	set->setValue("use_edl_files", use_edl_files);
 
+#ifdef MPLAYER_SUPPORT
+	set->setValue("use_playlist_option", use_playlist_option);
+#endif
+
 	set->setValue("prefer_ipv4", prefer_ipv4);
 
 	set->setValue("use_short_pathnames", use_short_pathnames);
@@ -833,6 +907,13 @@ void Preferences::save() {
 	set->setValue("use_mpris2", use_mpris2);
 #endif
 
+#ifdef MPV_SUPPORT
+	set->setValue("mpv_osd_media_info", mpv_osd_media_info);
+#endif
+#ifdef MPLAYER_SUPPORT
+	set->setValue("mplayer_osd_media_info", mplayer_osd_media_info);
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -851,10 +932,15 @@ void Preferences::save() {
 	set->setValue("resize_method", resize_method);
 
 #if STYLE_SWITCHING
-	set->setValue("style", style);
+	set->setValue("qt_style", style);
 #endif
 
-	set->setValue("move_when_dragging", move_when_dragging);
+	set->setValue("center_window", center_window);
+	set->setValue("center_window_if_outside", center_window_if_outside);
+
+#ifdef GLOBALSHORTCUTS
+	set->setValue("use_global_shortcuts", use_global_shortcuts);
+#endif
 
 	set->setValue("mouse_left_click_function", mouse_left_click_function);
 	set->setValue("mouse_right_click_function", mouse_right_click_function);
@@ -866,6 +952,8 @@ void Preferences::save() {
 	set->setValue("wheel_function_cycle", (int) wheel_function_cycle);
 	set->setValue("wheel_function_seeking_reverse", wheel_function_seeking_reverse);
 
+	set->setValue("drag_function", drag_function);
+
 	set->setValue("seeking1", seeking1);
 	set->setValue("seeking2", seeking2);
 	set->setValue("seeking3", seeking3);
@@ -933,19 +1021,33 @@ void Preferences::save() {
     /* ********
        TV (dvb)
        ******** */
-
+#ifdef TV_SUPPORT
 	set->beginGroup( "tv");
 	set->setValue("check_channels_conf_on_startup", check_channels_conf_on_startup);
 	set->setValue("initial_tv_deinterlace", initial_tv_deinterlace);
 	set->setValue("last_dvb_channel", last_dvb_channel);
 	set->setValue("last_tv_channel", last_tv_channel);
 	set->endGroup(); // tv
+#endif
 
 
     /* ********
        Network
        ******** */
 
+	set->beginGroup("streaming");
+	set->setValue("streaming_type", streaming_type);
+
+	#ifdef YOUTUBE_SUPPORT
+	set->beginGroup("streaming/youtube");
+	set->setValue("quality", yt_quality);
+	set->setValue("user_agent", yt_user_agent);
+	set->setValue("yt_use_https_main", yt_use_https_main);
+	set->setValue("yt_use_https_vi", yt_use_https_vi);
+	set->endGroup();
+	#endif
+	set->endGroup(); // streaming
+
 	set->beginGroup("proxy");
 	set->setValue("use_proxy", use_proxy);
 	set->setValue("type", proxy_type);
@@ -993,11 +1095,16 @@ void Preferences::save() {
 	set->setValue("initial_sub_pos", initial_sub_pos);
 
 	set->setValue("initial_volnorm", initial_volnorm);
+
+#ifdef INITIAL_BLACKBORDERS
+	set->setValue("initial_blackborders", initial_blackborders);
+#endif
+
 	set->setValue("initial_postprocessing", initial_postprocessing);
 
 	set->setValue("initial_deinterlace", initial_deinterlace);
 
-	set->setValue("initial_audio_channels", initial_audio_channels);
+	set->setValue("audio_channels", initial_audio_channels);
 	set->setValue("initial_stereo_mode", initial_stereo_mode);
 
 	set->setValue("initial_audio_track", initial_audio_track);
@@ -1013,8 +1120,10 @@ void Preferences::save() {
 	set->beginGroup( "mplayer_info");
 	set->setValue("mplayer_detected_version", mplayer_detected_version);
 	set->setValue("mplayer_user_supplied_version", mplayer_user_supplied_version);
+#ifdef MPLAYER2_SUPPORT
 	set->setValue("is_mplayer2", mplayer_is_mplayer2);
 	set->setValue("mplayer2_detected_version", mplayer2_detected_version);
+#endif
 	set->endGroup(); // mplayer_info
 
 
@@ -1108,6 +1217,7 @@ void Preferences::load() {
 	use_screenshot = set->value("use_screenshot", use_screenshot).toBool();
 	#ifdef MPV_SUPPORT
 	screenshot_template = set->value("screenshot_template", screenshot_template).toString();
+	screenshot_format = set->value("screenshot_format", screenshot_format).toString();
 	#endif
 	#if QT_VERSION >= 0x040400
 	screenshot_directory = set->value("screenshot_folder", screenshot_directory).toString();
@@ -1116,8 +1226,13 @@ void Preferences::load() {
 	screenshot_directory = set->value("screenshot_directory", screenshot_directory).toString();
 	#endif
 
-	dont_remember_media_settings = set->value("dont_remember_media_settings", dont_remember_media_settings).toBool();
-	dont_remember_time_pos = set->value("dont_remember_time_pos", dont_remember_time_pos).toBool();
+	#ifdef CAPTURE_STREAM
+	capture_directory = set->value("capture_directory", capture_directory).toString();
+	#endif
+
+	remember_media_settings = set->value("remember_media_settings", remember_media_settings).toBool();
+	remember_time_pos = set->value("remember_time_pos", remember_time_pos).toBool();
+	remember_stream_settings = set->value("remember_stream_settings", remember_stream_settings).toBool();
 
 	audio_lang = set->value("audio_lang", audio_lang).toString();
 	subtitle_lang = set->value("subtitle_lang", subtitle_lang).toString();
@@ -1128,9 +1243,12 @@ void Preferences::load() {
 	use_soft_video_eq = set->value("use_soft_video_eq", use_soft_video_eq).toBool();
 	use_slices = set->value("use_slices", use_slices ).toBool();
 	autoq = set->value("autoq", autoq).toInt();
-	add_blackborders_on_fullscreen = set->value("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen).toBool();
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef ADD_BLACKBORDERS_FS
+	add_blackborders_on_fullscreen = set->value("add_blackborders_on_fullscreen", add_blackborders_on_fullscreen).toBool();
+#endif
+
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	turn_screensaver_off = set->value("turn_screensaver_off", turn_screensaver_off).toBool();
 	#endif
@@ -1147,6 +1265,7 @@ void Preferences::load() {
 	vdpau.ffwmv3vdpau = set->value("vdpau_ffwmv3vdpau", vdpau.ffwmv3vdpau).toBool();
 	vdpau.ffvc1vdpau = set->value("vdpau_ffvc1vdpau", vdpau.ffvc1vdpau).toBool();
 	vdpau.ffodivxvdpau = set->value("vdpau_ffodivxvdpau", vdpau.ffodivxvdpau).toBool();
+	vdpau.ffhevcvdpau = set->value("vdpau_ffhevcvdpau", vdpau.ffhevcvdpau).toBool();
 	vdpau.disable_video_filters = set->value("vdpau_disable_video_filters", vdpau.disable_video_filters).toBool();
 #endif
 
@@ -1176,9 +1295,17 @@ void Preferences::load() {
 	osd_scale = set->value("osd_scale", osd_scale).toDouble();
 	subfont_osd_scale = set->value("subfont_osd_scale", subfont_osd_scale).toDouble();
 	osd_delay = set->value("osd_delay", osd_delay).toInt();
+#ifdef MPV_SUPPORT
+	osd_fractions = set->value("osd_fractions", osd_fractions).toBool();
+#endif
 
 	file_settings_method = set->value("file_settings_method", file_settings_method).toString();
 
+	tablet_mode = set->value("tablet_mode", tablet_mode).toBool();
+	#ifdef Q_OS_WIN
+	tablet_mode_change_answer = set->value("tablet_mode_change_answer", tablet_mode_change_answer).toString();
+	#endif
+
 	set->endGroup(); // General
 
 
@@ -1213,14 +1340,19 @@ void Preferences::load() {
 
 	set->beginGroup( "performance");
 
+#ifdef Q_OS_WIN
 	priority = set->value("priority", priority).toInt();
+#endif
 	frame_drop = set->value("frame_drop", frame_drop).toBool();
 	hard_frame_drop = set->value("hard_frame_drop", hard_frame_drop).toBool();
 	coreavc = set->value("coreavc", coreavc).toBool();
 	h264_skip_loop_filter = (H264LoopFilter) set->value("h264_skip_loop_filter", h264_skip_loop_filter).toInt();
 	HD_height = set->value("HD_height", HD_height).toInt();
 
+#ifdef OBSOLETE_FAST_AUDIO_CHANGE
 	fast_audio_change = (OptionState) set->value("fast_audio_change", fast_audio_change).toInt();
+#endif
+
 #if !SMART_DVD_CHAPTERS
 	fast_chapter_change = set->value("fast_chapter_change", fast_chapter_change).toBool();
 #endif
@@ -1228,31 +1360,18 @@ void Preferences::load() {
 	threads = set->value("threads", threads).toInt();
 	hwdec = set->value("hwdec", hwdec).toString();
 
+	cache_auto = set->value("cache_auto", cache_auto).toBool();
 	cache_for_files = set->value("cache_for_files", cache_for_files).toInt();
 	cache_for_streams = set->value("cache_for_streams", cache_for_streams).toInt();
 	cache_for_dvds = set->value("cache_for_dvds", cache_for_dvds).toInt();
 	cache_for_vcds = set->value("cache_for_vcds", cache_for_vcds).toInt();
 	cache_for_audiocds = set->value("cache_for_audiocds", cache_for_audiocds).toInt();
+#ifdef TV_SUPPORT
 	cache_for_tv = set->value("cache_for_tv", cache_for_tv).toInt();
+#endif
 
 	set->endGroup(); // performance
 
-#ifdef YOUTUBE_SUPPORT
-	set->beginGroup("youtube");
-	enable_yt_support = set->value("enable_yt_support", enable_yt_support).toBool();
-	yt_quality = set->value("quality", yt_quality).toInt();
-	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
-	yt_use_https_main = set->value("yt_use_https_main", yt_use_https_main).toBool();
-	yt_use_https_vi = set->value("yt_use_https_vi", yt_use_https_vi).toBool();
-	set->endGroup();
-#endif
-
-#ifdef MPV_SUPPORT
-	set->beginGroup("streaming");
-	enable_streaming_sites = set->value("enable_streaming_sites", enable_streaming_sites).toBool();
-	set->endGroup();
-#endif
-
 
     /* *********
        Subtitles
@@ -1286,7 +1405,7 @@ void Preferences::load() {
 	user_forced_ass_style = set->value("user_forced_ass_style", user_forced_ass_style).toString();
 
 	freetype_support = set->value("freetype_support", freetype_support).toBool();
-#ifdef Q_OS_WIN
+#ifdef FONTS_HACK
 	use_windowsfontdir = set->value("use_windowsfontdir", use_windowsfontdir).toBool();
 #endif
 
@@ -1341,6 +1460,10 @@ void Preferences::load() {
 
 	use_edl_files = set->value("use_edl_files", use_edl_files).toBool();
 
+#ifdef MPLAYER_SUPPORT
+	use_playlist_option = set->value("use_playlist_option", use_playlist_option).toBool();
+#endif
+
 	prefer_ipv4 = set->value("prefer_ipv4", prefer_ipv4).toBool();
 
 	use_short_pathnames = set->value("use_short_pathnames", use_short_pathnames).toBool();
@@ -1359,6 +1482,13 @@ void Preferences::load() {
 	use_mpris2 = set->value("use_mpris2", use_mpris2).toBool();
 #endif
 
+#ifdef MPV_SUPPORT
+	mpv_osd_media_info = set->value("mpv_osd_media_info", mpv_osd_media_info).toString();
+#endif
+#ifdef MPLAYER_SUPPORT
+	mplayer_osd_media_info = set->value("mplayer_osd_media_info", mplayer_osd_media_info).toString();
+#endif
+
 	set->endGroup(); // advanced
 
 
@@ -1377,10 +1507,15 @@ void Preferences::load() {
 	resize_method = set->value("resize_method", resize_method).toInt();
 
 #if STYLE_SWITCHING
-	style = set->value("style", style).toString();
+	style = set->value("qt_style", style).toString();
 #endif
 
-	move_when_dragging = set->value("move_when_dragging", move_when_dragging).toBool();
+	center_window = set->value("center_window", center_window).toBool();
+	center_window_if_outside = set->value("center_window_if_outside", center_window_if_outside).toBool();
+
+#ifdef GLOBALSHORTCUTS
+	use_global_shortcuts = set->value("use_global_shortcuts", use_global_shortcuts).toBool();
+#endif
 
 	mouse_left_click_function = set->value("mouse_left_click_function", mouse_left_click_function).toString();
 	mouse_right_click_function = set->value("mouse_right_click_function", mouse_right_click_function).toString();
@@ -1395,6 +1530,8 @@ void Preferences::load() {
 	}
 	wheel_function_seeking_reverse = set->value("wheel_function_seeking_reverse", wheel_function_seeking_reverse).toBool();
 
+	drag_function = set->value("drag_function", drag_function).toInt();
+
 	seeking1 = set->value("seeking1", seeking1).toInt();
 	seeking2 = set->value("seeking2", seeking2).toInt();
 	seeking3 = set->value("seeking3", seeking3).toInt();
@@ -1462,19 +1599,33 @@ void Preferences::load() {
     /* ********
        TV (dvb)
        ******** */
-
+#ifdef TV_SUPPORT
 	set->beginGroup( "tv");
 	check_channels_conf_on_startup = set->value("check_channels_conf_on_startup", check_channels_conf_on_startup).toBool();
 	initial_tv_deinterlace = set->value("initial_tv_deinterlace", initial_tv_deinterlace).toInt();
 	last_dvb_channel = set->value("last_dvb_channel", last_dvb_channel).toString();
 	last_tv_channel = set->value("last_tv_channel", last_tv_channel).toString();
 	set->endGroup(); // tv
+#endif
 
 
     /* ********
        Network
        ******** */
 
+	set->beginGroup("streaming");
+	streaming_type = set->value("streaming_type", streaming_type).toInt();
+
+	#ifdef YOUTUBE_SUPPORT
+	set->beginGroup("streaming/youtube");
+	yt_quality = set->value("quality", yt_quality).toInt();
+	yt_user_agent = set->value("user_agent", yt_user_agent).toString();
+	yt_use_https_main = set->value("yt_use_https_main", yt_use_https_main).toBool();
+	yt_use_https_vi = set->value("yt_use_https_vi", yt_use_https_vi).toBool();
+	set->endGroup();
+	#endif
+	set->endGroup(); // streaming
+
 	set->beginGroup("proxy");
 	use_proxy = set->value("use_proxy", use_proxy).toBool();
 	proxy_type = set->value("type", proxy_type).toInt();
@@ -1519,11 +1670,16 @@ void Preferences::load() {
 	initial_sub_pos = set->value("initial_sub_pos", initial_sub_pos).toInt();
 
 	initial_volnorm = set->value("initial_volnorm", initial_volnorm).toBool();
+
+#ifdef INITIAL_BLACKBORDERS
+	initial_blackborders = set->value("initial_blackborders", initial_blackborders).toBool();
+#endif
+
 	initial_postprocessing = set->value("initial_postprocessing", initial_postprocessing).toBool();
 
 	initial_deinterlace = set->value("initial_deinterlace", initial_deinterlace).toInt();
 
-	initial_audio_channels = set->value("initial_audio_channels", initial_audio_channels).toInt();
+	initial_audio_channels = set->value("audio_channels", initial_audio_channels).toInt();
 	initial_stereo_mode = set->value("initial_stereo_mode", initial_stereo_mode).toInt();
 
 	initial_audio_track = set->value("initial_audio_track", initial_audio_track).toInt();
@@ -1539,9 +1695,10 @@ void Preferences::load() {
 	set->beginGroup( "mplayer_info");
 	mplayer_detected_version = set->value("mplayer_detected_version", mplayer_detected_version).toInt();
 	mplayer_user_supplied_version = set->value("mplayer_user_supplied_version", mplayer_user_supplied_version).toInt();
+#ifdef MPLAYER2_SUPPORT
 	mplayer_is_mplayer2 = set->value("is_mplayer2", mplayer_is_mplayer2).toBool();
 	mplayer2_detected_version = set->value("mplayer2_detected_version", mplayer2_detected_version).toString();
-
+#endif
 	set->endGroup(); // mplayer_info
 
 
@@ -1615,6 +1772,18 @@ void Preferences::load() {
 #endif
 
 
+	// Fix some options
+	if (vo == "player_default") vo = "";
+	if (ao == "player_default") ao = "";
+
+#if QT_VERSION < 0x050000
+	if (style.toLower() == "fusion") style = "";
+#endif
+
+	// Remove old option names
+	if (set->contains("gui/style")) set->remove("gui/style");
+
+#ifdef USE_CONFIG_VERSION
 	qDebug("Preferences::load: config_version: %d, CURRENT_CONFIG_VERSION: %d", config_version, CURRENT_CONFIG_VERSION);
 	// Fix some values if config is old
 	if (config_version < CURRENT_CONFIG_VERSION) {
@@ -1633,7 +1802,7 @@ void Preferences::load() {
 		*/
 		if (config_version <= 4) {
 			use_slices = false;
-			osd = None;
+			osd = Seek;
 			frame_drop = false;
 			cache_for_files = 2048;
 			cache_for_streams = 2048;
@@ -1644,8 +1813,10 @@ void Preferences::load() {
 		}
 		config_version = CURRENT_CONFIG_VERSION;
 	}
+#endif
 
-#ifdef Q_OS_WIN
+#if defined(MPV_SUPPORT) && defined(MPLAYER_SUPPORT)
+	#ifdef Q_OS_WIN
 	// Check if the mplayer binary exists and try to fix it
 	if (!QFile::exists(mplayer_bin)) {
 		qWarning("mplayer_bin '%s' doesn't exist", mplayer_bin.toLatin1().constData());
@@ -1660,16 +1831,16 @@ void Preferences::load() {
 			fixed = true;
 		}
 		else
-		if (QFile::exists("mplayer/mpv.exe")) {
-			mplayer_bin = "mplayer/mpv.exe";
+		if (QFile::exists("mpv/mpv.exe")) {
+			mplayer_bin = "mpv/mpv.exe";
 			fixed = true;
 		}
 		if (fixed) {
 			qWarning("mplayer_bin changed to '%s'", mplayer_bin.toLatin1().constData());
 		}
 	}
-#endif
-#ifdef Q_OS_LINUX
+	#endif
+	#ifdef Q_OS_LINUX
 	if (!QFile::exists(mplayer_bin)) {
 		QString app_path = Helper::findExecutable(mplayer_bin);
 		//qDebug("Preferences::load: app_path: %s", app_path.toUtf8().constData());
@@ -1688,10 +1859,10 @@ void Preferences::load() {
 			}
 		}
 	}
+	#endif
 #endif
 }
 
-#endif // NO_USE_INI_FILES
 
 double Preferences::monitor_aspect_double() {
 	qDebug("Preferences::monitor_aspect_double");
