@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,24 +28,40 @@
 #include "prefsubtitles.h"
 #include "prefadvanced.h"
 #include "prefplaylist.h"
-#include "preftv.h"
 #include "prefupdates.h"
+#include "prefnetwork.h"
+#include "infowindow.h"
+#include "preferences.h"
+#include "images.h"
+#include <QVBoxLayout>
+#include <QDebug>
+
+#ifdef TV_SUPPORT
+#include "preftv.h"
+#endif
 
 #if USE_ASSOCIATIONS
 #include "prefassociations.h"
 #endif
 
-#include "preferences.h"
-
-#include <QVBoxLayout>
-#include <QTextBrowser>
-
-#include "images.h"
+#if QT_VERSION >= 0x050000
+#include "myscroller.h"
+#endif
 
 PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	: QDialog(parent, f )
+	, icon_mode(false)
 {
 	setupUi(this);
+	/*
+	sections->setUniformItemSizes(true);
+	sections->setResizeMode(QListView::Adjust);
+	*/
+	sections->setMovement(QListView::Static);
+
+#if QT_VERSION >= 0x050000
+	MyScroller::setScroller(sections->viewport());
+#endif
 
 	// Setup buttons
 	okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -54,16 +70,10 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	helpButton = buttonBox->button(QDialogButtonBox::Help);
 	connect( applyButton, SIGNAL(clicked()), this, SLOT(apply()) );
 	connect( helpButton, SIGNAL(clicked()), this, SLOT(showHelp()) );
-	
 
 	setWindowIcon( Images::icon("logo") );
 
-	help_window = new QTextBrowser(this);
-	help_window->setWindowFlags(Qt::Window);
-	help_window->resize(300, 450);
-	//help_window->adjustSize();
-	help_window->setWindowTitle( tr("SMPlayer - Help") );
-	help_window->setWindowIcon( Images::icon("logo") );
+	help_window = new InfoWindow(this);
 
 	page_general = new PrefGeneral;
 	addSection( page_general );
@@ -86,8 +96,10 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	page_playlist = new PrefPlaylist;
 	addSection( page_playlist );
 
+#ifdef TV_SUPPORT
 	page_tv = new PrefTV;
 	addSection( page_tv );
+#endif
 
 #if USE_ASSOCIATIONS
 	page_associations = new PrefAssociations;
@@ -97,6 +109,9 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 	page_updates = new PrefUpdates;
 	addSection( page_updates );
 
+	page_network = new PrefNetwork;
+	addSection( page_network );
+
 	page_advanced = new PrefAdvanced;
 	addSection( page_advanced );
 
@@ -105,10 +120,31 @@ PreferencesDialog::PreferencesDialog(QWidget * parent, Qt::WindowFlags f)
 
 	//adjustSize();
 	retranslateStrings();
+
+	/*
+	qDebug() << "PreferencesDialog: movement:" << sections->movement();
+	qDebug() << "PreferencesDialog: maximumWidth:" << sections->maximumWidth();
+	qDebug() << "PreferencesDialog: spacing:" << sections->spacing();
+	*/
 }
 
-PreferencesDialog::~PreferencesDialog()
-{
+PreferencesDialog::~PreferencesDialog() {
+}
+
+void PreferencesDialog::setIconMode(bool b) {
+	qDebug() << "PreferencesDialog::setIconMode:" << b;
+
+	if (b) {
+		sections->setUniformItemSizes(true);
+		sections->setViewMode(QListView::IconMode);
+		sections->setMaximumWidth(128);
+		sections->setSpacing(12);
+	} else {
+		sections->setUniformItemSizes(false);
+		sections->setViewMode(QListView::ListMode);
+		sections->setMaximumWidth(16777215);
+		sections->setSpacing(0);
+	}
 }
 
 void PreferencesDialog::showSection(Section s) {
@@ -124,6 +160,7 @@ void PreferencesDialog::retranslateStrings() {
 		PrefWidget * w = (PrefWidget*) pages->widget(n);
 		sections->item(n)->setText( w->sectionName() );
 		sections->item(n)->setIcon( w->sectionIcon() );
+		sections->item(n)->setToolTip( w->sectionName() );
 	}
 
 	if (help_window->isVisible()) {
@@ -132,14 +169,14 @@ void PreferencesDialog::retranslateStrings() {
 	}
 
 	help_window->setWindowTitle( tr("SMPlayer - Help") );
+	help_window->setWindowIcon( Images::icon("logo") );
 
-	// Qt 4.2 doesn't update the buttons' text
-#if QT_VERSION < 0x040300
-	okButton->setText( tr("OK") );
-	cancelButton->setText( tr("Cancel") );
+	// Some Qt versions don't provide translated strings
+	// for these buttons
+	okButton->setText( tr("&OK") );
+	cancelButton->setText( tr("&Cancel") );
 	applyButton->setText( tr("Apply") );
 	helpButton->setText( tr("Help") );
-#endif
 }
 
 void PreferencesDialog::accept() {
@@ -177,8 +214,11 @@ void PreferencesDialog::setData(Preferences * pref) {
 	page_subtitles->setData(pref);
 	page_advanced->setData(pref);
 	page_playlist->setData(pref);
+#ifdef TV_SUPPORT
 	page_tv->setData(pref);
+#endif
 	page_updates->setData(pref);
+	page_network->setData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->setData(pref);
@@ -194,8 +234,11 @@ void PreferencesDialog::getData(Preferences * pref) {
 	page_subtitles->getData(pref);
 	page_advanced->getData(pref);
 	page_playlist->getData(pref);
+#ifdef TV_SUPPORT
 	page_tv->getData(pref);
+#endif
 	page_updates->getData(pref);
+	page_network->getData(pref);
 
 #if USE_ASSOCIATIONS
 	page_associations->getData(pref);
@@ -211,8 +254,11 @@ bool PreferencesDialog::requiresRestart() {
 	if (!need_restart) need_restart = page_subtitles->requiresRestart();
 	if (!need_restart) need_restart = page_advanced->requiresRestart();
 	if (!need_restart) need_restart = page_playlist->requiresRestart();
+#ifdef TV_SUPPORT
 	if (!need_restart) need_restart = page_tv->requiresRestart();
+#endif
 	if (!need_restart) need_restart = page_updates->requiresRestart();
+	if (!need_restart) need_restart = page_network->requiresRestart();
 
 	return need_restart;
 }
