@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,10 +26,24 @@
 #include "vdpauproperties.h"
 #include "playerid.h"
 
-#if USE_ALSA_DEVICES || USE_DSOUND_DEVICES
+#if USE_ALSA_DEVICES || USE_PULSEAUDIO_DEVICES || USE_XV_ADAPTORS || USE_DSOUND_DEVICES
 #include "deviceinfo.h"
 #endif
 
+#ifdef MPLAYER_MPV_SELECTION
+ #define PLAYER_COMBO_MPLAYER 0
+ #define PLAYER_COMBO_MPV 1
+ #define PLAYER_COMBO_OTHER 2
+
+ #ifdef Q_OS_WIN
+  #define PLAYER_COMBO_MPLAYER_PATH "mplayer/mplayer.exe"
+  #define PLAYER_COMBO_MPV_PATH "mpv/mpv.exe"
+ #else
+  #define PLAYER_COMBO_MPLAYER_PATH "mplayer"
+  #define PLAYER_COMBO_MPV_PATH "mpv"
+ #endif
+#endif
+
 PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	: PrefWidget(parent, f )
 {
@@ -51,12 +65,18 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 #if USE_ALSA_DEVICES
 	alsa_devices = DeviceInfo::alsaDevices();
 #endif
+#if USE_MPV_ALSA_DEVICES
+	mpv_alsa_devices = DeviceInfo::mpvAlsaDevices();
+#endif
+#if USE_PULSEAUDIO_DEVICES
+	pa_devices = DeviceInfo::paDevices();
+#endif
 #if USE_XV_ADAPTORS
 	xv_adaptors = DeviceInfo::xvAdaptors();
 #endif
 
 	// Screensaver
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef Q_OS_WIN
 	screensaver_check->hide();
 	#ifndef SCREENSAVER_OFF
 	turn_screensaver_off_check->hide();
@@ -76,18 +96,39 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	shutdown_widget->hide();
 #endif
 
-#ifndef MPV_SUPPORT
+#ifndef ADD_BLACKBORDERS_FS
+	blackborders_on_fs_check->hide();
+#endif
+
+#ifndef INITIAL_BLACKBORDERS
+	blackborders_check->hide();
+#endif
+
+#ifdef MPV_SUPPORT
+	screenshot_format_combo->addItems(QStringList() << "png" << "ppm" << "pgm" << "pgmyuv" << "tga" << "jpg" << "jpeg");
+#else
 	screenshot_template_label->hide();
 	screenshot_template_edit->hide();
+	screenshot_format_label->hide();
+	screenshot_format_combo->hide();
 #endif
 
 	// Channels combo
+	channels_combo->addItem( "0", MediaSettings::ChDefault );
 	channels_combo->addItem( "2", MediaSettings::ChStereo );
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
 	channels_combo->addItem( "6", MediaSettings::ChFull51 );
 	channels_combo->addItem( "7", MediaSettings::ChFull61 );
 	channels_combo->addItem( "8", MediaSettings::ChFull71 );
 
+#ifdef MPLAYER_MPV_SELECTION
+	connect(player_combo, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(player_combo_changed(int)));
+#else
+	player_combo->hide();
+	player_spacer->changeSize(0, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);
+#endif
+
 	connect(vo_combo, SIGNAL(currentIndexChanged(int)),
             this, SLOT(vo_combo_changed(int)));
 	connect(ao_combo, SIGNAL(currentIndexChanged(int)),
@@ -105,17 +146,27 @@ QString PrefGeneral::sectionName() {
 }
 
 QPixmap PrefGeneral::sectionIcon() {
-	return Images::icon("pref_general", 22);
+	return Images::icon("pref_general");
 }
 
 void PrefGeneral::retranslateStrings() {
 	retranslateUi(this);
 
-	channels_combo->setItemText(0, tr("2 (Stereo)") );
-	channels_combo->setItemText(1, tr("4 (4.0 Surround)") );
-	channels_combo->setItemText(2, tr("6 (5.1 Surround)") );
-	channels_combo->setItemText(3, tr("7 (6.1 Surround)") );
-	channels_combo->setItemText(4, tr("8 (7.1 Surround)") );
+#ifdef MPLAYER_MPV_SELECTION
+	int player_item = player_combo->currentIndex();
+	player_combo->clear();
+	player_combo->addItem("mplayer", PLAYER_COMBO_MPLAYER);
+	player_combo->addItem("mpv", PLAYER_COMBO_MPV);
+	player_combo->addItem(tr("Other..."), PLAYER_COMBO_OTHER);
+	player_combo->setCurrentIndex(player_item);
+#endif
+
+	channels_combo->setItemText(0, tr("Default") );
+	channels_combo->setItemText(1, tr("2 (Stereo)") );
+	channels_combo->setItemText(2, tr("4 (4.0 Surround)") );
+	channels_combo->setItemText(3, tr("6 (5.1 Surround)") );
+	channels_combo->setItemText(4, tr("7 (6.1 Surround)") );
+	channels_combo->setItemText(5, tr("8 (7.1 Surround)") );
 
 	int deinterlace_item = deinterlace_combo->currentIndex();
 	deinterlace_combo->clear();
@@ -141,7 +192,7 @@ void PrefGeneral::retranslateStrings() {
     volume_icon->setPixmap( Images::icon("speaker") );
 	*/
 
-	mplayerbin_edit->setCaption(tr("Select the mplayer executable"));
+	mplayerbin_edit->setCaption(tr("Select the %1 executable").arg(PLAYER_NAME));
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	mplayerbin_edit->setFilter(tr("Executables") +" (*.exe)");
 #else
@@ -159,7 +210,9 @@ void PrefGeneral::retranslateStrings() {
            "Example: <b>es|esp|spa</b> will select the track if it matches with "
             "<i>es</i>, <i>esp</i> or <i>spa</i>."));
 
+#ifndef MPLAYER_MPV_SELECTION
 	executable_label->setText( tr("%1 &executable:").arg(PLAYER_NAME) );
+#endif
 
 	createHelp();
 }
@@ -171,42 +224,16 @@ void PrefGeneral::setData(Preferences * pref) {
 	setScreenshotDir( pref->screenshot_directory );
 #ifdef MPV_SUPPORT
 	screenshot_template_edit->setText( pref->screenshot_template );
+	setScreenshotFormat(pref->screenshot_format);
 #endif
 
-	QString vo = pref->vo;
-	if (vo.isEmpty()) {
-#ifdef Q_OS_WIN
-		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA) {
-			vo = "direct3d,";
-		} else {
-			vo = "directx,";
-		}
-#else
-#ifdef Q_OS_OS2
-		vo = "kva";
-#else
-		vo = "xv,";
-#endif
-#endif
-	}
-	setVO( vo );
+	setVO( pref->vo );
+	setAO( pref->ao );
 
-	QString ao = pref->ao;
+	setRememberSettings( pref->remember_media_settings );
+	setRememberTimePos( pref->remember_time_pos );
+	remember_streams_check->setChecked(pref->remember_stream_settings);
 
-#ifdef Q_OS_OS2
-	if (ao.isEmpty()) {
-		if (pref->mplayer_detected_version >= MPLAYER_KAI_VERSION) {
-			ao = "kai";
-		} else {
-			ao = "dart";
-		}
-	}
-#endif
-
-	setAO( ao );
-
-	setRememberSettings( !pref->dont_remember_media_settings );
-	setRememberTimePos( !pref->dont_remember_time_pos );
 	setFileSettingsMethod( pref->file_settings_method );
 	setAudioLang( pref->audio_lang );
 	setSubtitleLang( pref->subtitle_lang );
@@ -233,10 +260,18 @@ void PrefGeneral::setData(Preferences * pref) {
 	setDoubleBuffer( pref->use_double_buffer );
 	setUseSlices( pref->use_slices );
 	setStartInFullscreen( pref->start_in_fullscreen );
+
+#ifdef ADD_BLACKBORDERS_FS
 	setBlackbordersOnFullscreen( pref->add_blackborders_on_fullscreen );
+#endif
+
+#ifdef INITIAL_BLACKBORDERS
+	blackborders_check->setChecked(pref->initial_blackborders);
+#endif
+
 	setAutoq( pref->autoq );
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	setTurnScreensaverOff( pref->turn_screensaver_off );
 	#endif
@@ -283,16 +318,15 @@ void PrefGeneral::getData(Preferences * pref) {
 	TEST_AND_SET(pref->screenshot_directory, screenshotDir());
 #ifdef MPV_SUPPORT
 	TEST_AND_SET(pref->screenshot_template, screenshot_template_edit->text());
+	TEST_AND_SET(pref->screenshot_format, screenshotFormat());
 #endif
 
 	TEST_AND_SET(pref->vo, VO());
 	TEST_AND_SET(pref->ao, AO());
 
-	bool dont_remember_ms = !rememberSettings();
-    TEST_AND_SET(pref->dont_remember_media_settings, dont_remember_ms);
-
-	bool dont_remember_time = !rememberTimePos();
-	TEST_AND_SET(pref->dont_remember_time_pos, dont_remember_time);
+	TEST_AND_SET(pref->remember_media_settings, rememberSettings());
+	TEST_AND_SET(pref->remember_time_pos, rememberTimePos());
+	TEST_AND_SET(pref->remember_stream_settings, remember_streams_check->isChecked());
 
 	if (pref->file_settings_method != fileSettingsMethod()) {
 		pref->file_settings_method = fileSettingsMethod();
@@ -327,13 +361,21 @@ void PrefGeneral::getData(Preferences * pref) {
 	TEST_AND_SET(pref->use_double_buffer, doubleBuffer());
 	TEST_AND_SET(pref->use_slices, useSlices());
 	pref->start_in_fullscreen = startInFullscreen();
+
+#ifdef ADD_BLACKBORDERS_FS
 	if (pref->add_blackborders_on_fullscreen != blackbordersOnFullscreen()) {
 		pref->add_blackborders_on_fullscreen = blackbordersOnFullscreen();
 		if (pref->fullscreen) requires_restart = true;
 	}
+#endif
+
+#ifdef INITIAL_BLACKBORDERS
+	pref->initial_blackborders = blackborders_check->isChecked();
+#endif
+
 	TEST_AND_SET(pref->autoq, autoq());
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	TEST_AND_SET(pref->turn_screensaver_off, turnScreensaverOff());
 	#endif
@@ -365,32 +407,32 @@ void PrefGeneral::updateDriverCombos() {
 	vo_combo->clear();
 	ao_combo->clear();
 
-	vo_combo->addItem(tr("Default"), "player_default");
-	ao_combo->addItem(tr("Default"), "player_default");
+	vo_combo->addItem(tr("Default"), "");
+	ao_combo->addItem(tr("Default"), "");
 
 	QString vo;
 	for ( int n = 0; n < vo_list.count(); n++ ) {
 		vo = vo_list[n].name();
-#ifdef Q_OS_WIN
+		#ifdef Q_OS_WIN
 		if ( vo == "directx" ) {
 			vo_combo->addItem( "directx (" + tr("fast") + ")", "directx" );
 			vo_combo->addItem( "directx (" + tr("slow") + ")", "directx:noaccel" );
 		}
 		else
-#else
-#ifdef Q_OS_OS2
+		#else
+		#ifdef Q_OS_OS2
 		if ( vo == "kva") {
 			vo_combo->addItem( "kva (" + tr("fast") + ")", "kva" );
 			vo_combo->addItem( "kva (" + tr("snap mode") + ")", "kva:snap" );
 			vo_combo->addItem( "kva (" + tr("slower dive mode") + ")", "kva:dive" );
 		}
 		else
-#else
+		#else
 		/*
 		if (vo == "xv") vo_combo->addItem( "xv (" + tr("fastest") + ")", vo);
 		else
 		*/
-#if USE_XV_ADAPTORS
+		#if USE_XV_ADAPTORS
 		if ((vo == "xv") && (!xv_adaptors.isEmpty())) {
 			vo_combo->addItem(vo, vo);
 			for (int n=0; n < xv_adaptors.count(); n++) {
@@ -399,9 +441,9 @@ void PrefGeneral::updateDriverCombos() {
 			}
 		}
 		else
-#endif // USE_XV_ADAPTORS
-#endif
-#endif
+		#endif // USE_XV_ADAPTORS
+		#endif
+		#endif
 		if (vo == "x11") vo_combo->addItem( "x11 (" + tr("slow") + ")", vo);
 		else
 		if (vo == "gl") {
@@ -435,28 +477,42 @@ void PrefGeneral::updateDriverCombos() {
 	for ( int n = 0; n < ao_list.count(); n++) {
 		ao = ao_list[n].name();
 		ao_combo->addItem( ao, ao );
-#ifdef Q_OS_OS2
+		/*
+		#ifdef Q_OS_OS2
 		if ( ao == "kai") {
 			ao_combo->addItem( "kai (" + tr("uniaud mode") + ")", "kai:uniaud" );
 			ao_combo->addItem( "kai (" + tr("dart mode") + ")", "kai:dart" );
 		}
-#endif
-#if USE_ALSA_DEVICES
+		#endif
+		*/
+		#if USE_ALSA_DEVICES
 		if ((ao == "alsa") && (!alsa_devices.isEmpty())) {
 			for (int n=0; n < alsa_devices.count(); n++) {
-				ao_combo->addItem( "alsa (" + alsa_devices[n].ID().toString() + " - " + alsa_devices[n].desc() + ")", 
-                                   "alsa:device=hw=" + alsa_devices[n].ID().toString() );
+				ao_combo->addItem( DeviceInfo::printableName("alsa", alsa_devices[n]), DeviceInfo::internalName("alsa", alsa_devices[n]) );
 			}
 		}
-#endif
-#if USE_DSOUND_DEVICES
+		#endif
+		#if USE_MPV_ALSA_DEVICES
+		if ((ao == "alsa") && (!mpv_alsa_devices.isEmpty())) {
+			for (int n=0; n < mpv_alsa_devices.count(); n++) {
+				ao_combo->addItem( DeviceInfo::printableName("alsa", mpv_alsa_devices[n]), DeviceInfo::internalName("alsa", mpv_alsa_devices[n]) );
+			}
+		}
+		#endif
+		#if USE_PULSEAUDIO_DEVICES
+		if ((ao == "pulse") && (!pa_devices.isEmpty())) {
+			for (int n=0; n < pa_devices.count(); n++) {
+				ao_combo->addItem( DeviceInfo::printableName("pulse", pa_devices[n]), DeviceInfo::internalName("pulse", pa_devices[n]) );
+			}
+		}
+		#endif
+		#if USE_DSOUND_DEVICES
 		if ((ao == "dsound") && (!dsound_devices.isEmpty())) {
 			for (int n=0; n < dsound_devices.count(); n++) {
-				ao_combo->addItem( "dsound (" + dsound_devices[n].ID().toString() + " - " + dsound_devices[n].desc() + ")", 
-                                   "dsound:device=" + dsound_devices[n].ID().toString() );
+				ao_combo->addItem( DeviceInfo::printableName("dsound", dsound_devices[n]), DeviceInfo::internalName("dsound", dsound_devices[n]) );
 			}
 		}
-#endif
+		#endif
 	}
 	ao_combo->addItem( tr("User defined..."), "user_defined" );
 
@@ -466,9 +522,32 @@ void PrefGeneral::updateDriverCombos() {
 
 void PrefGeneral::setMplayerPath( QString path ) {
 	mplayerbin_edit->setText( path );
+
+#ifdef MPLAYER_MPV_SELECTION
+	if (path == PLAYER_COMBO_MPLAYER_PATH) {
+		player_combo->setCurrentIndex(PLAYER_COMBO_MPLAYER);
+	}
+	else
+	if (path == PLAYER_COMBO_MPV_PATH) {
+		player_combo->setCurrentIndex(PLAYER_COMBO_MPV);
+	}
+	else {
+		player_combo->setCurrentIndex(PLAYER_COMBO_OTHER);
+	}
+#endif
 }
 
 QString PrefGeneral::mplayerPath() {
+#ifdef MPLAYER_MPV_SELECTION
+	if (player_combo->currentIndex() == PLAYER_COMBO_MPLAYER) {
+		return PLAYER_COMBO_MPLAYER_PATH;
+	}
+	else
+	if (player_combo->currentIndex() == PLAYER_COMBO_MPV) {
+		return PLAYER_COMBO_MPV_PATH;
+	}
+	else
+#endif
 	return mplayerbin_edit->text();
 }
 
@@ -485,9 +564,21 @@ void PrefGeneral::setScreenshotDir( QString path ) {
 }
 
 QString PrefGeneral::screenshotDir() {
-	return screenshot_edit->text();
+	return screenshot_edit->text().trimmed();
 }
 
+#ifdef MPV_SUPPORT
+void PrefGeneral::setScreenshotFormat(const QString format) {
+	int i = screenshot_format_combo->findText(format);
+	if (i < 0) i = 0;
+	screenshot_format_combo->setCurrentIndex(i);
+}
+
+QString PrefGeneral::screenshotFormat() {
+	return screenshot_format_combo->currentText();
+}
+#endif
+
 void PrefGeneral::setVO( QString vo_driver ) {
 	int idx = vo_combo->findData( vo_driver );
 	if (idx != -1) {
@@ -786,7 +877,7 @@ bool PrefGeneral::startInFullscreen() {
 	return start_fullscreen_check->isChecked();
 }
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef Q_OS_WIN
 #ifdef AVOID_SCREENSAVER
 void PrefGeneral::setAvoidScreensaver(bool b) {
 	avoid_screensaver_check->setChecked(b);
@@ -817,6 +908,7 @@ bool PrefGeneral::disableScreensaver() {
 }
 #endif
 
+#ifdef ADD_BLACKBORDERS_FS
 void PrefGeneral::setBlackbordersOnFullscreen(bool b) {
 	blackborders_on_fs_check->setChecked(b);
 }
@@ -824,6 +916,7 @@ void PrefGeneral::setBlackbordersOnFullscreen(bool b) {
 bool PrefGeneral::blackbordersOnFullscreen() {
 	return blackborders_on_fs_check->isChecked();
 }
+#endif
 
 void PrefGeneral::setAutoq(int n) {
 	autoq_spin->setValue(n);
@@ -841,6 +934,21 @@ Preferences::OptionState PrefGeneral::scaleTempoFilter() {
 	return scaletempo_combo->state();
 }
 
+#ifdef MPLAYER_MPV_SELECTION
+void PrefGeneral::player_combo_changed(int idx) {
+	qDebug("PrefGeneral::player_combo_changed: %d", idx);
+	int d = player_combo->itemData(idx).toInt();
+	if (d == PLAYER_COMBO_OTHER) {
+		player_spacer->changeSize(0, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);
+		mplayerbin_edit->setVisible(true);
+		//mplayerbin_edit->setFocus();
+	} else {
+		player_spacer->changeSize(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+		mplayerbin_edit->setVisible(false);
+	}
+}
+#endif
+
 void PrefGeneral::vo_combo_changed(int idx) {
 	qDebug("PrefGeneral::vo_combo_changed: %d", idx);
 	bool visible = (vo_combo->itemData(idx).toString() == "user_defined");
@@ -848,7 +956,7 @@ void PrefGeneral::vo_combo_changed(int idx) {
 	vo_user_defined_edit->setFocus();
 
 #ifndef Q_OS_WIN
-	bool vdpau_button_visible = (vo_combo->itemData(idx).toString() == "vdpau");
+	bool vdpau_button_visible = (vo_combo->itemData(idx).toString() == "vdpau" && mplayerPath().contains("mplayer"));
 	vdpau_button->setVisible(vdpau_button_visible);
 #endif
 }
@@ -871,6 +979,7 @@ void PrefGeneral::on_vdpau_button_clicked() {
 	d.setffwmv3vdpau(vdpau.ffwmv3vdpau);
 	d.setffvc1vdpau(vdpau.ffvc1vdpau);
 	d.setffodivxvdpau(vdpau.ffodivxvdpau);
+	d.setffhevcvdpau(vdpau.ffhevcvdpau);
 
 	d.setDisableFilters(vdpau.disable_video_filters);
 
@@ -880,6 +989,7 @@ void PrefGeneral::on_vdpau_button_clicked() {
 		vdpau.ffwmv3vdpau = d.ffwmv3vdpau();
 		vdpau.ffvc1vdpau = d.ffvc1vdpau();
 		vdpau.ffodivxvdpau = d.ffodivxvdpau();
+		vdpau.ffhevcvdpau = d.ffhevcvdpau();
 
 		vdpau.disable_video_filters = d.disableFilters();
 	}
@@ -891,6 +1001,12 @@ void PrefGeneral::createHelp() {
 
 	addSectionTitle(tr("General"));
 
+#ifdef MPLAYER_MPV_SELECTION
+	setWhatsThis(player_combo, tr("Multimedia engine"),
+		tr("Select which multimedia engine you want to use, either MPlayer or mpv.") +" "+
+		tr("The option 'other' allows you to manually select the path of the executable.") );
+#endif
+
 	setWhatsThis(mplayerbin_edit, tr("%1 executable").arg(PLAYER_NAME),
 		tr("Here you must specify the %1 "
            "executable that SMPlayer will use.").arg(PLAYER_NAME) + "<br><b>" +
@@ -907,6 +1023,9 @@ void PrefGeneral::createHelp() {
            "of the file when you open it again. This option works only with "
            "regular files (not with DVDs, CDs, URLs...).") );
 
+	setWhatsThis(remember_streams_check, tr("Remember settings for streams"),
+		tr("When this option is enabled the settings for online streams will be remembered as well."));
+
 	setWhatsThis(filesettings_method_combo, tr("Method to store the file settings"),
 		tr("This option allows to change the way the file settings would be "
            "stored. The following options are available:") +"<ul><li>" + 
@@ -933,8 +1052,18 @@ void PrefGeneral::createHelp() {
 		   "%2 adds a 4 digit number padded with zeros.").arg("%F").arg("%04n") + " " +
 		tr("For a full list of the template specifiers visit this link:") + 
 		" <a href=\"http://mpv.io/manual/stable/#options-screenshot-template\">"
-		"http://mpv.io/manual/stable/#options-screenshot-template</a>" + "<br>" +
-		tr("This option only works with mpv.") );
+		"http://mpv.io/manual/stable/#options-screenshot-template</a>"
+		#ifdef MPLAYER_SUPPORT
+		+ "<br>" + tr("This option only works with mpv.")
+		#endif
+		);
+
+	setWhatsThis(screenshot_format_combo, tr("Format for screenshots"),
+		tr("This option allows to choose the image file type used for saving screenshots.")
+		#ifdef MPLAYER_SUPPORT
+		+ " " + tr("This option only works with mpv.")
+		#endif
+		);
 #endif
 
 	setWhatsThis(pause_if_hidden_check, tr("Pause when minimized"),
@@ -955,17 +1084,7 @@ void PrefGeneral::createHelp() {
 	addSectionTitle(tr("Video"));
 
 	setWhatsThis(vo_combo, tr("Video output driver"),
-		tr("Select the video output driver. %1 provides the best performance.")
-#ifdef Q_OS_WIN
-		  .arg("<b><i>directx</i></b>")
-#else
-#ifdef Q_OS_OS2
-		  .arg("<b><i>kva</i></b>")
-#else
-		  .arg("<b><i>xv</i></b>")
-#endif
-#endif
-		);
+		tr("Select the video output driver."));
 
 #if !defined(Q_OS_WIN) && !defined(Q_OS_OS2)
 	/*
@@ -988,6 +1107,12 @@ void PrefGeneral::createHelp() {
            "videos opened.") +" "+ 
         tr("<b>Note:</b> This option won't be used for TV channels.") );
 
+#ifdef INITIAL_BLACKBORDERS
+	setWhatsThis(blackborders_check, tr("Add black borders for subtitles by default"),
+		tr("If this option is enabled, black borders will be added to the image "
+           "by default on new opened files."));
+#endif
+
 	setWhatsThis(zoom_spin, tr("Default zoom"),
 		tr("This option sets the default zoom which will be used for "
            "new videos.") );
@@ -1018,6 +1143,7 @@ void PrefGeneral::createHelp() {
 		tr("If this option is checked, all videos will start to play in "
            "fullscreen mode.") );
 
+#ifdef ADD_BLACKBORDERS_FS
 	setWhatsThis(blackborders_on_fs_check, tr("Add black borders on fullscreen"),
 		tr("If this option is enabled, black borders will be added to the "
            "image in fullscreen mode. This allows subtitles to be displayed "
@@ -1025,8 +1151,9 @@ void PrefGeneral::createHelp() {
  		tr("This option will be ignored if MPlayer uses its own window, as "
            "some video drivers (like gl) are already able to display the "
            "subtitles automatically in the black borders.") */ );
+#endif
 
-#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+#ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
 	setWhatsThis(turn_screensaver_off_check, tr("Switch screensaver off"),
 		tr("This option switches the screensaver off just before starting to "
@@ -1053,24 +1180,7 @@ void PrefGeneral::createHelp() {
 	addSectionTitle(tr("Audio"));
 
 	setWhatsThis(ao_combo, tr("Audio output driver"),
-		tr("Select the audio output driver.") 
-#ifndef Q_OS_WIN
-#ifdef Q_OS_OS2
-        + " " +
-		tr("%1 is the recommended one. %2 is only available on older MPlayer (before version %3)")
-           .arg("<b><i>kai</i></b>")
-           .arg("<b><i>dart</i></b>")
-           .arg(MPLAYER_KAI_VERSION)
-#else
-        + " " + 
-		tr("%1 is the recommended one. Try to avoid %2 and %3, they are slow "
-           "and can have an impact on performance.")
-           .arg("<b><i>alsa</i></b>")
-           .arg("<b><i>esd</i></b>")
-           .arg("<b><i>arts</i></b>")
-#endif
-#endif
-		);
+		tr("Select the audio output driver."));
 
 	setWhatsThis(audio_equalizer_check, tr("Enable the audio equalizer"),
 		tr("Check this option if you want to use the audio equalizer.") );
@@ -1086,7 +1196,7 @@ void PrefGeneral::createHelp() {
            "option is enabled.") );
 
 	setWhatsThis(channels_combo, tr("Channels by default"),
-		tr("Requests the number of playback channels. MPlayer "
+		tr("Requests the number of playback channels. %1 "
            "asks the decoder to decode the audio into as many channels as "
            "specified. Then it is up to the decoder to fulfill the "
            "requirement. This is usually only important when playing "
@@ -1094,11 +1204,10 @@ void PrefGeneral::createHelp() {
            "the decoding by default and correctly downmixes the audio "
            "into the requested number of channels. "
            "<b>Note</b>: This option is honored by codecs (AC3 only), "
-           "filters (surround) and audio output drivers (OSS at least).") );
+           "filters (surround) and audio output drivers (OSS at least).").arg(PLAYER_NAME) );
 
 	setWhatsThis(scaletempo_combo, tr("High speed playback without altering pitch"),
-		tr("Allows to change the playback speed without altering pitch. "
-           "Requires at least MPlayer dev-SVN-r24924.") );
+		tr("Allows to change the playback speed without altering pitch.") );
 
 	setWhatsThis(global_volume_check, tr("Global volume"),
 		tr("If this option is checked, the same volume will be used for "
