@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2017 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -66,6 +66,14 @@ ToolbarEditor::ToolbarEditor( QWidget* parent, Qt::WindowFlags f )
 ToolbarEditor::~ToolbarEditor() {
 }
 
+void ToolbarEditor::setIconSize(int size) {
+	iconsize_spin->setValue(size);
+}
+
+int ToolbarEditor::iconSize() {
+	return iconsize_spin->value();
+}
+
 void ToolbarEditor::populateList(QListWidget * w, QList<QAction *> actions_list, bool add_separators) {
 	w->clear();
 
@@ -77,15 +85,21 @@ void ToolbarEditor::populateList(QListWidget * w, QList<QAction *> actions_list,
 				QListWidgetItem * i = new QListWidgetItem;
 				QString text = fixname(action->text(), action->objectName());
 				i->setText(text + " ("+ action->objectName() +")");
-				i->setIcon(action->icon());
+				QIcon icon = action->icon();
+				if (icon.isNull()) {
+					icon = Images::icon("empty_icon");
+				}
+				i->setIcon(icon);
 				i->setData(Qt::UserRole, action->objectName());
 				w->addItem(i);
 			}
 			else
 			if ((action->isSeparator()) && (add_separators)) {
 				QListWidgetItem * i = new QListWidgetItem;
-				i->setText(tr("(separator)"));
+				//i->setText(tr("(separator)"));
+				i->setText("---------");
 				i->setData(Qt::UserRole, "separator");
+				i->setIcon(Images::icon("empty_icon"));
 				w->addItem(i);
 			}
 		}
@@ -177,8 +191,10 @@ void ToolbarEditor::on_separator_button_clicked() {
 	qDebug("ToolbarEditor::on_separator_button_clicked");
 
 	QListWidgetItem * i = new QListWidgetItem;
-	i->setText(tr("(separator)"));
+	//i->setText(tr("(separator)"));
+	i->setText("---------");
 	i->setData(Qt::UserRole, "separator");
+	i->setIcon(Images::icon("empty_icon"));
 
 	int row = active_actions_list->currentRow();
 	if (row > -1) {
@@ -242,9 +258,17 @@ QString ToolbarEditor::fixname(const QString & name, const QString & action_name
 	else
 	if (action_name == "timelabel_action") s = tr("Display time");
 	else
+	if (action_name == "current_timelabel_action") s = tr("Current time");
+	else
+	if (action_name == "total_timelabel_action") s = tr("Total time");
+	else
+	if (action_name == "remaining_timelabel_action") s = tr("Remaining time");
+	else
 	if (action_name == "rewindbutton_action") s = tr("3 in 1 rewind");
 	else
 	if (action_name == "forwardbutton_action") s = tr("3 in 1 forward");
+	else
+	if (action_name == "quick_access_menu") s = tr("Quick access menu");
 	return s;
 }
 
